@@ -2,7 +2,7 @@
  * Copyright (C) 2020 Damir Porobic <damir.porobic@gmx.com>
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
+ * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
+ * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
@@ -48,3 +48,13 @@ bool KsnipWaylandConfig::snippingAreaMagnifyingGlassEnabled() const
 {
 	return false;
 }
+
+bool KsnipWaylandConfig::isForceGenericWaylandEnabledReadOnly() const
+{
+    return false;
+}
+
+bool KsnipWaylandConfig::isScaleGenericWaylandScreenshotEnabledReadOnly() const
+{
+    return false;
+}
