@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2016 Damir Porobic <https://github.com/damirporobic>
+ * Copyright (C) 2021 Damir Porobic <damir.porobic@gmx.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,32 +15,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- *
  */
 
-#ifndef X11IMAGEGRABBER_H
-#define X11IMAGEGRABBER_H
+#ifndef KSNIP_X11IMAGEGRABBER_H
+#define KSNIP_X11IMAGEGRABBER_H
 
-#include "AbstractRectAreaImageGrabber.h"
+#include "BaseX11ImageGrabber.h"
 #include "X11Wrapper.h"
-#include "src/common/platform/HdpiScaler.h"
-#include "src/gui/snippingArea/LinuxSnippingArea.h"
 
-class X11ImageGrabber : public AbstractRectAreaImageGrabber
+class X11ImageGrabber : public BaseX11ImageGrabber
 {
 public:
-    explicit X11ImageGrabber();
-	~X11ImageGrabber() override;
-
-protected:
-	QRect fullScreenRect() const override;
-	QRect activeWindowRect() const override;
-	bool isSnippingAreaBackgroundTransparent() const override;
-	CursorDto getCursorWithPosition() const override;
-
-private:
-    X11Wrapper *mX11Wrapper;
-	HdpiScaler mHdpiScaler;
+	X11ImageGrabber();
+	~X11ImageGrabber() override = default;
 };
 
-#endif // X11IMAGEGRABBER_H
+
+#endif //KSNIP_X11IMAGEGRABBER_H
