@@ -21,10 +21,10 @@
 #define KSNIP_FILEDIALOGADAPTERFACTORY_H
 
 #include "FileDialogAdapter.h"
-#include "SnapFileDialogAdapter.h"
 
-#if defined(__linux__)
+#if defined(UNIX_X11)
 #include "src/common/platform/PlatformChecker.h"
+#include "SnapFileDialogAdapter.h"
 #endif
 
 class FileDialogAdapterFactory
