@@ -21,6 +21,8 @@
 #define KSNIP_CAPTUREMODES_H
 
 #include <QMetaType>
+#include <QHash>
+#include <QObject>
 
 enum class CaptureModes
 {
@@ -33,6 +35,10 @@ enum class CaptureModes
     Portal
 };
 
+inline uint qHash(const CaptureModes captureMode, uint seed) {
+	return qHash(static_cast<int>(captureMode), seed);
+}
+
 Q_DECLARE_METATYPE(CaptureModes)
 
 #endif // KSNIP_CAPTUREMODES_H
