@@ -19,18 +19,28 @@
 
 #include "FileUrlHelper.h"
 
-QString FileUrlHelper::parse(const QString &text)
+QString FileUrlHelper::toPath(const QString &url)
+{
+	auto path = url;
+	return path.remove(filePrefix());
+}
+
+QString FileUrlHelper::toFileUrl(const QString &path)
+{
+	return filePrefix() + path;
+}
+
+QString FileUrlHelper::filePrefix()
 {
-	auto url = text;
 #if defined(__APPLE__)
-	return url.remove(QStringLiteral("file://"));
+	return QLatin1String("file://");
 #endif
 
-#if defined(__linux__)
-	return url.remove(QStringLiteral("file://"));
+#if defined(UNIX_X11)
+	return QLatin1String("file://");
 #endif
 
 #if  defined(_WIN32)
-	return url.remove(QStringLiteral("file:///"));
+	return QLatin1String("file:///");
 #endif
 }
