@@ -21,24 +21,7 @@
 
 QString CommandRunner::getEnvironmentVariable(const QString& variable) const
 {
-    QString value;
-
-    auto command = variable.trimmed();
-    command.prepend(QLatin1Literal("echo $"));
-    command.append(QLatin1Literal(" 2>&1"));
-
-    auto stream = popen(command.toLatin1(), "r");
-
-    if (stream) {
-        char buffer[mMaxBuffer];
-        while (!feof(stream)) {
-            if (fgets(buffer, mMaxBuffer, stream) != nullptr) {
-                value.append(buffer);
-            }
-        }
-        pclose(stream);
-    }
-    return value;
+	return qgetenv(variable.toLatin1());
 }
 
 bool CommandRunner::isEnvironmentVariableSet(const QString &variable) const
