@@ -29,27 +29,50 @@ NotifyOperation::NotifyOperation(IToastService *toastService, const QString &tit
 	mToastService(toastService),
 	mTitle(title),
 	mMessage(message),
-	mNotificationType(notificationType)
+	mNotificationType(notificationType),
+	mConfig(KsnipConfigProvider::instance())
 {
 	Q_ASSERT(mToastService != nullptr);
 }
 
 bool NotifyOperation::execute()
 {
-	switch (mNotificationType) {
-		case NotificationTypes::Information:
-			mToastService->showInfoToast(mTitle, mMessage, mContentUrl);
-			qInfo("%s: %s", qPrintable(mTitle), qPrintable(mMessage));
-			break;
-		case NotificationTypes::Warning:
-			mToastService->showWarningToast(mTitle, mMessage, mContentUrl);
-			qWarning("%s: %s", qPrintable(mTitle), qPrintable(mMessage));
-			break;
-		case NotificationTypes::Critical:
-			mToastService->showCriticalToast(mTitle, mMessage, mContentUrl);
-			qCritical("%s: %s", qPrintable(mTitle), qPrintable(mMessage));
-			break;
+	if(mConfig->trayIconNotificationsEnabled()) {
+		notifyViaToastMessage();
 	}
+
+	notifyViaConsoleMessage();
+
 	return true;
 }
 
+void NotifyOperation::notifyViaToastMessage() const
+{
+	switch (mNotificationType) {
+		case NotificationTypes::Information:
+			mToastService->showInfoToast(mTitle, mMessage, mContentUrl);
+			break;
+		case NotificationTypes::Warning:
+			mToastService->showWarningToast(mTitle, mMessage, mContentUrl);
+			break;
+		case NotificationTypes::Critical:
+			mToastService->showCriticalToast(mTitle, mMessage, mContentUrl);
+			break;
+	}
+}
+
+void NotifyOperation::notifyViaConsoleMessage() const
+{
+	switch (mNotificationType) {
+		case NotificationTypes::Information:
+			qInfo("%s: %s", qPrintable(mTitle), qPrintable(mMessage));
+			break;
+		case NotificationTypes::Warning:
+			qWarning("%s: %s", qPrintable(mTitle), qPrintable(mMessage));
+			break;
+		case NotificationTypes::Critical:
+			qCritical("%s: %s", qPrintable(mTitle), qPrintable(mMessage));
+			break;
+	}
+}
+
