@@ -63,6 +63,8 @@ protected:
 	virtual bool isBackgroundTransparent() const;
     virtual void setFullScreen() = 0;
 	virtual QRect getSnippingAreaGeometry() const = 0;
+	virtual QPoint getLocalCursorPosition() const;
+	virtual void grabKeyboardFocus();
 
 private:
 	KsnipConfig *mConfig;
