@@ -19,18 +19,18 @@
 
 #include "WidgetVisibilityHandlerFactory.h"
 
-WidgetVisibilityHandler *WidgetVisibilityHandlerFactory::create(QWidget *widget, KsnipConfig *config)
+WidgetVisibilityHandler *WidgetVisibilityHandlerFactory::create(QWidget *widget)
 {
 #if defined(__APPLE__) || defined(_WIN32)
-	return new WidgetVisibilityHandler(widget, config);
+	return new WidgetVisibilityHandler(widget);
 #endif
 
-#if defined(__linux__)
+#if defined(UNIX_X11)
 	auto platformChecker = PlatformChecker::instance();
 	if (platformChecker->isWayland() && platformChecker->isGnome()) {
-		return new GnomeWaylandWidgetVisibilityHandler(widget, config);
+		return new GnomeWaylandWidgetVisibilityHandler(widget);
 	} else {
-		return new WidgetVisibilityHandler(widget, config);
+		return new WidgetVisibilityHandler(widget);
 	}
 #endif
 }
