@@ -24,7 +24,7 @@
 #include "WidgetVisibilityHandler.h"
 #endif
 
-#if defined(__linux__)
+#if defined(UNIX_X11)
 #include "GnomeWaylandWidgetVisibilityHandler.h"
 #include "src/common/platform/PlatformChecker.h"
 #endif
@@ -32,7 +32,7 @@
 class WidgetVisibilityHandlerFactory
 {
 public:
-	static WidgetVisibilityHandler* create(QWidget *widget, KsnipConfig *config);
+	static WidgetVisibilityHandler *create(QWidget *widget);
 };
 
 #endif //KSNIP_WIDGETVISIBILITYHANDLERRFACTORY_H
