@@ -27,24 +27,94 @@
         <source>Donate</source>
         <translation>Támogatás</translation>
     </message>
+    <message>
+        <source>Contact</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AboutTab</name>
-    <message>
-        <source>Screenshot Tool</source>
-        <translation>Képlopó</translation>
-    </message>
     <message>
         <source>License: </source>
         <translation>Licenc </translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Kérlek használd </translation>
+        <source>Screenshot and Annotation Tool</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionSettingTab</name>
+    <message>
+        <source>Name</source>
+        <translation>Név</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> a hiba jelentéséhez.</translation>
+        <source>Shortcut</source>
+        <translation>Parancsikon</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Töröl</translation>
+    </message>
+    <message>
+        <source>Take Capture</source>
+        <translation>Kép készítése</translation>
+    </message>
+    <message>
+        <source>Include Cursor</source>
+        <translation>Kurzort is</translation>
+    </message>
+    <message>
+        <source>Delay</source>
+        <translation>Késleltetés</translation>
+    </message>
+    <message>
+        <source>s</source>
+        <translation>mp</translation>
+    </message>
+    <message>
+        <source>Capture Mode</source>
+        <translation>Képkészítési mód</translation>
+    </message>
+    <message>
+        <source>Show image in Pin Window</source>
+        <translation>Kép mutatása a rögzített ablakban</translation>
+    </message>
+    <message>
+        <source>Copy image to Clipboard</source>
+        <translation>kép másolása vágólapra</translation>
+    </message>
+    <message>
+        <source>Upload image</source>
+        <translation>Kép feltöltése</translation>
+    </message>
+    <message>
+        <source>Open image parent directory</source>
+        <translation>Kép megnyitása szülőkönyvtárban</translation>
+    </message>
+    <message>
+        <source>Save image</source>
+        <translation>Kép mentése</translation>
+    </message>
+    <message>
+        <source>Hide Main Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionsSettings</name>
+    <message>
+        <source>Add</source>
+        <translation>Hozzáad</translation>
+    </message>
+    <message>
+        <source>Actions Settings</source>
+        <translation>Műveletek beállításai</translation>
+    </message>
+    <message>
+        <source>Action</source>
+        <translation>Művelet</translation>
     </message>
 </context>
 <context>
@@ -60,14 +130,6 @@
 </context>
 <context>
     <name>AnnotationSettings</name>
-    <message>
-        <source>Paint Item Shadows</source>
-        <translation>Festék árnyék</translation>
-    </message>
-    <message>
-        <source>When enabled, paint items cast shadows.</source>
-        <translation>Ha engedélyezve van, a festék elemek árnyat vetnek.</translation>
-    </message>
     <message>
         <source>Smooth Painter Paths</source>
         <translation>Sima festő útvonal</translation>
@@ -90,50 +152,6 @@ make them more smooth.</source>
 csökken a toll és a jelölő pontossága,
 de simábbá teszi.</translation>
     </message>
-    <message>
-        <source>Text Font</source>
-        <translation>Szöveg betűtipus</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Text Paint Item.</source>
-        <translation>Állítsd be a betűtipust a szöveghez.</translation>
-    </message>
-    <message>
-        <source>Bold</source>
-        <translation>Félkövér</translation>
-    </message>
-    <message>
-        <source>Italic</source>
-        <translation>Dőlt</translation>
-    </message>
-    <message>
-        <source>Underline</source>
-        <translation>Aláhúzott</translation>
-    </message>
-    <message>
-        <source>Numbering Font</source>
-        <translation>Sorszámozó betűtipus</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Numbering Paint Item.</source>
-        <translation>Állítsd be a betűtipust a számozáshoz.</translation>
-    </message>
-    <message>
-        <source>Watermark Image</source>
-        <translation>Vízjel-kép</translation>
-    </message>
-    <message>
-        <source>Update</source>
-        <translation>Frissítés</translation>
-    </message>
-    <message>
-        <source>Rotate Watermark</source>
-        <translation>Vízjel forgatása</translation>
-    </message>
-    <message>
-        <source>When enabled, Watermark will be added with a rotation of 45°</source>
-        <translation>Ha engedélyezve van, a vízjel 45°-kal elforgatva lesz hozzáadva a képhez</translation>
-    </message>
     <message>
         <source>Annotator Settings</source>
         <translation>Kiemelés beállításai</translation>
@@ -146,6 +164,34 @@ de simábbá teszi.</translation>
         <source>Switch to Select Tool after drawing Item</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number Tool Seed change updates all Number Items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disabling this option causes changes of the number tool
+seed to affect only new items but not existing items.
+Disabling this option allows having duplicate numbers.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Canvas Color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Canvas background color for annotation area.
+Changing color affects only new annotation areas.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Item after drawing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>With this option enabled the item gets selected after
+being created, allowing changing settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -167,32 +213,10 @@ A módosításhoz érvényesítéséhez a program újraindítása szükséges.</
         <source>Application Settings</source>
         <translation>Alkalmazás beállítások</translation>
     </message>
-    <message>
-        <source>Use Tray Icon</source>
-        <translation>Tálcaikon használata</translation>
-    </message>
-    <message>
-        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
-Change requires restart.</source>
-        <translation>Ha engedélyezve van, a tálcaikon rákerül a tálcára, ha az oprenszer ablakkezelője támogatja ezt a funkciót.
-A változtatás érvenyesítéséhez újra kell indítani a programot.</translation>
-    </message>
-    <message>
-        <source>Minimize to Tray</source>
-        <translation>Kicsinyítés a tálcára</translation>
-    </message>
-    <message>
-        <source>Close to Tray</source>
-        <translation>Bezáráskor lehelyezés a tálcára</translation>
-    </message>
     <message>
         <source>Automatically copy new captures to clipboard</source>
         <translation>Az új képernyőmentéseket automatikusan másolja a vágólapra</translation>
     </message>
-    <message>
-        <source>Auto Hide Tabs</source>
-        <translation>Fülek automatikus elrejtése</translation>
-    </message>
     <message>
         <source>Use Tabs</source>
         <translation type="unfinished"></translation>
@@ -205,10 +229,6 @@ A változtatás érvenyesítéséhez újra kell indítani a programot.</translat
         <source>Run ksnip as single instance</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Start Minimized to Tray</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Hide Tabbar when only one Tab is used.</source>
         <translation type="unfinished"></translation>
@@ -224,13 +244,30 @@ a new start of all instances.</source>
         <source>Remember Main Window position on move and load on startup</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Auto hide Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>On startup hide Toolbar and Annotation Settings.
+Docks visibility can be toggled with the Tab Key.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto resize to content</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically resize Main Window to fit content image.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
-    <message>
-        <source>The Author:</source>
-        <translation>A szerzőről:</translation>
-    </message>
     <message>
         <source>Contributors:</source>
         <translation>Közreműködők:</translation>
@@ -264,7 +301,7 @@ a new start of all instances.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Feature Implementation</source>
+        <source>The Authors:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -286,60 +323,82 @@ Do you want to save it?</source>
         <source>New</source>
         <translation>Új</translation>
     </message>
-    <message>
-        <source>Rectangular Area</source>
-        <translation>Terület</translation>
-    </message>
     <message>
         <source>Draw a rectangular area with your mouse</source>
         <translation>Rajzolj (kijelölő) területet az egérrel</translation>
     </message>
-    <message>
-        <source>Full Screen (All Monitors)</source>
-        <translation>Teljes képernyő (minden monitor)</translation>
-    </message>
     <message>
         <source>Capture full screen including all monitors</source>
         <translation>A teljes képernyő rögzítése, beleértve az összes monitort</translation>
     </message>
-    <message>
-        <source>Current Screen</source>
-        <translation>Aktuális képernyő</translation>
-    </message>
     <message>
         <source>Capture screen where the mouse is located</source>
         <translation>Aktuális képernyő rögzítése, ahol az egér található</translation>
     </message>
-    <message>
-        <source>Active Window</source>
-        <translation>Aktív ablak</translation>
-    </message>
     <message>
         <source>Capture window that currently has focus</source>
         <translation>Aktív ablak rögzítése, ahol a fókusz van</translation>
     </message>
-    <message>
-        <source>Window Under Cursor</source>
-        <translation>Kurzor alatti ablak</translation>
-    </message>
     <message>
         <source>Capture that is currently under the mouse cursor</source>
         <translation>Az egérmutató alatt lévő ablak rögzítése</translation>
     </message>
-    <message>
-        <source>Last Rectangular Area</source>
-        <translation>Legutoljára használt kijelölés</translation>
-    </message>
     <message>
         <source>Capture a screenshot of the last selected rectangular area</source>
         <translation>Képernyőkép rögzítése a legutoljára használt kijelölés szerint</translation>
     </message>
     <message>
-        <source>Screenshot Portal</source>
+        <source>Uses the screenshot Portal for taking screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ContactTab</name>
+    <message>
+        <source>Community</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Uses the screenshot Portal for taking screenshot</source>
+        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>please join our </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> server.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bug Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please use </source>
+        <translation type="unfinished">Kérlek használd </translation>
+    </message>
+    <message>
+        <source> to report bugs.</source>
+        <translation type="unfinished"> a hiba jelentéséhez.</translation>
+    </message>
+</context>
+<context>
+    <name>CopyAsDataUriOperation</name>
+    <message>
+        <source>Failed to copy to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to copy to clipboard as base64 encoded image.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard as base64 encoded image.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -386,6 +445,44 @@ Do you want to continue?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>EmptyActionSettingTab</name>
+    <message>
+        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>EnumTranslator</name>
+    <message>
+        <source>Rectangular Area</source>
+        <translation type="unfinished">Terület</translation>
+    </message>
+    <message>
+        <source>Last Rectangular Area</source>
+        <translation type="unfinished">Legutoljára használt kijelölés</translation>
+    </message>
+    <message>
+        <source>Full Screen (All Monitors)</source>
+        <translation type="unfinished">Teljes képernyő (minden monitor)</translation>
+    </message>
+    <message>
+        <source>Current Screen</source>
+        <translation type="unfinished">Aktuális képernyő</translation>
+    </message>
+    <message>
+        <source>Active Window</source>
+        <translation type="unfinished">Aktív ablak</translation>
+    </message>
+    <message>
+        <source>Window Under Cursor</source>
+        <translation type="unfinished">Kurzor alatti ablak</translation>
+    </message>
+    <message>
+        <source>Screenshot Portal</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
@@ -475,22 +572,23 @@ Do you want to continue?</source>
         <source>Global HotKeys</source>
         <translation>Globális gyorsbillentyűk</translation>
     </message>
-    <message>
-        <source>HotKeys are currently supported only for Windows and X11</source>
-        <translation>A gyorsbillentyűk jelenleg csak Windows-on és X11-en támogatottak</translation>
-    </message>
     <message>
         <source>Capture Last Rect Area</source>
         <translation>Legutoljára használt kijelölés szerinti rögzítés</translation>
     </message>
     <message>
         <source>Clear</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Töröl</translation>
     </message>
     <message>
         <source>Capture using Portal</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>HotKeys are currently supported only for Windows and X11.
+Disabling this option makes also the action shortcuts ksnip only.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImageGrabberSettings</name>
@@ -504,66 +602,10 @@ screenshots.</source>
         <translation>Az egérkurzor látszódni fog
 a képernyőképen.</translation>
     </message>
-    <message>
-        <source>Freeze Image while snipping</source>
-        <translation>Kép fagyasztása rögzítéskor</translation>
-    </message>
-    <message>
-        <source>Show magnifying glass on snipping area</source>
-        <translation>Mutassa a nagyítót rögzítéskor</translation>
-    </message>
-    <message>
-        <source>Show a magnifying glass which zooms into
-the background image. This option only works
-with &apos;Freeze Image while snipping&apos; enabled.</source>
-        <translation>Mutasson a nagyítót, ami nagyítja a háttérképet.
-Ez az opció csak akkor működik, ha a
-&apos;Kép fagyasztása rögzítéskor&apos; engedélyezve van.</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area rulers</source>
-        <translation>Mutassa a vonalzót a rögzítés területén</translation>
-    </message>
-    <message>
-        <source>Horizontal and vertical lines going from
-desktop edges to cursor on snipping area.</source>
-        <translation>Vízszintes és függőleges vonalak az asztal széleitől
-a rögzítési területen lévő kurzorig.</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area position and size info</source>
-        <translation>Mutassa a rögzítési terület helyét és méretét</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor color</source>
-        <translation>Kurzor színe a rögzítés területén</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor thickness</source>
-        <translation>Kurzor vastagsága a rögzítési területen</translation>
-    </message>
     <message>
         <source>Image Grabber</source>
         <translation>Képlopás</translation>
     </message>
-    <message>
-        <source>When enabled will freeze the background while
-selecting a rectangular region. It also changes
-the behavior of delayed screenshots, with this
-option enabled the delay happens before the
-snipping area is shown and with the option disabled
-the delay happens after the snipping area is shown.
-This feature is always disabled for Wayland and always
-enabled for MacOs.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When left mouse button is not pressed the position
-is shown, when the mouse button is pressed,
-the size of the select area is shown left
-and above from the captured area.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Force Generic Wayland Screenshot</source>
         <translation type="unfinished"></translation>
@@ -592,22 +634,6 @@ Change in this option require a ksnip restart.</source>
         <source>Show Main Window after capturing screenshot</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Show Main Window after capturing a new screenshot
-when the Main Window was hidden or minimized.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Allow resizing rect area selection</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When enabled will, after selecting a rect
-area, allow resizing the selection. When
-done resizing the selection can be confirmed
-by pressing return.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Hide Main Window during screenshot</source>
         <translation type="unfinished"></translation>
@@ -617,11 +643,8 @@ by pressing return.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Sets the color of the snipping area cursor.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sets the thickness of the snipping area cursor.</source>
+        <source>Show Main Window after capturing a new screenshot
+when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -713,10 +736,6 @@ by pressing return.</source>
         <source>Waiting for imgur.com…</source>
         <translation>Várakozás az imgur.com-ra…</translation>
     </message>
-    <message>
-        <source>Username:</source>
-        <translation>Felhasználónév:</translation>
-    </message>
     <message>
         <source>Imgur.com token successfully updated.</source>
         <translation>imgur.com azonosító sikeresen feltöltve.</translation>
@@ -742,6 +761,21 @@ by pressing return.</source>
 Changing requires restart.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clear Token</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoadImageFromFileOperation</name>
+    <message>
+        <source>Unable to open image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open image from path %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainToolBar</name>
@@ -826,10 +860,6 @@ másodpercben megadva.</translation>
         <source>Scale</source>
         <translation>Lépték</translation>
     </message>
-    <message>
-        <source>Scale Screen Capture</source>
-        <translation>Képernyőkép lépték</translation>
-    </message>
     <message>
         <source>Quit</source>
         <translation>Kilépés</translation>
@@ -890,10 +920,6 @@ másodpercben megadva.</translation>
         <source>Paste Embedded</source>
         <translation>Beágyazott beillesztés</translation>
     </message>
-    <message>
-        <source>Upload capture to external source</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Pin</source>
         <translation type="unfinished"></translation>
@@ -930,6 +956,46 @@ másodpercben megadva.</translation>
         <source>Open Images</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy as data URI</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open &amp;Recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify Canvas</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload triggerCapture to external source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy triggerCapture to system clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate Image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1205,6 +1271,176 @@ When omitted, everything is copied.</source>
         <source>Stickers</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Watermark</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaResizerInfoText</name>
+    <message>
+        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys to move the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSelectorInfoText</name>
+    <message>
+        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to resize selection after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Operation will be canceled after 60 sec when no selection made.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSettings</name>
+    <message>
+        <source>Freeze Image while snipping</source>
+        <translation type="unfinished">Kép fagyasztása rögzítéskor</translation>
+    </message>
+    <message>
+        <source>When enabled will freeze the background while
+selecting a rectangular region. It also changes
+the behavior of delayed screenshots, with this
+option enabled the delay happens before the
+snipping area is shown and with the option disabled
+the delay happens after the snipping area is shown.
+This feature is always disabled for Wayland and always
+enabled for MacOs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show magnifying glass on snipping area</source>
+        <translation type="unfinished">Mutassa a nagyítót rögzítéskor</translation>
+    </message>
+    <message>
+        <source>Show a magnifying glass which zooms into
+the background image. This option only works
+with &apos;Freeze Image while snipping&apos; enabled.</source>
+        <translation type="unfinished">Mutasson a nagyítót, ami nagyítja a háttérképet.
+Ez az opció csak akkor működik, ha a
+&apos;Kép fagyasztása rögzítéskor&apos; engedélyezve van.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area rulers</source>
+        <translation type="unfinished">Mutassa a vonalzót a rögzítés területén</translation>
+    </message>
+    <message>
+        <source>Horizontal and vertical lines going from
+desktop edges to cursor on snipping area.</source>
+        <translation type="unfinished">Vízszintes és függőleges vonalak az asztal széleitől
+a rögzítési területen lévő kurzorig.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area position and size info</source>
+        <translation type="unfinished">Mutassa a rögzítési terület helyét és méretét</translation>
+    </message>
+    <message>
+        <source>When left mouse button is not pressed the position
+is shown, when the mouse button is pressed,
+the size of the select area is shown left
+and above from the captured area.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow resizing rect area selection by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will, after selecting a rect
+area, allow resizing the selection. When
+done resizing the selection can be confirmed
+by pressing return.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Snipping Area info text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor color</source>
+        <translation type="unfinished">Kurzor színe a rögzítés területén</translation>
+    </message>
+    <message>
+        <source>Sets the color of the snipping area cursor.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor thickness</source>
+        <translation type="unfinished">Kurzor vastagsága a rögzítési területen</translation>
+    </message>
+    <message>
+        <source>Sets the thickness of the snipping area cursor.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area adorner color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sets the color of all adorner elements
+on the snipping area.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area Transparency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Alpha for not selected region on snipping area.
+Smaller number is more transparent.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
@@ -1230,7 +1466,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Hozzáad</translation>
     </message>
     <message>
         <source>Remove</source>
@@ -1248,6 +1484,64 @@ When omitted, everything is copied.</source>
         <translation>Szerkesztő mutatása</translation>
     </message>
 </context>
+<context>
+    <name>TrayIconSettings</name>
+    <message>
+        <source>Use Tray Icon</source>
+        <translation type="unfinished">Tálcaikon használata</translation>
+    </message>
+    <message>
+        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
+Change requires restart.</source>
+        <translation type="unfinished">Ha engedélyezve van, a tálcaikon rákerül a tálcára, ha az oprenszer ablakkezelője támogatja ezt a funkciót.
+A változtatás érvenyesítéséhez újra kell indítani a programot.</translation>
+    </message>
+    <message>
+        <source>Minimize to Tray</source>
+        <translation type="unfinished">Kicsinyítés a tálcára</translation>
+    </message>
+    <message>
+        <source>Start Minimized to Tray</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close to Tray</source>
+        <translation type="unfinished">Bezáráskor lehelyezés a tálcára</translation>
+    </message>
+    <message>
+        <source>Show Editor</source>
+        <translation type="unfinished">Szerkesztő mutatása</translation>
+    </message>
+    <message>
+        <source>Capture</source>
+        <translation type="unfinished">Képlopás</translation>
+    </message>
+    <message>
+        <source>Default Tray Icon action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Action that is triggered by left clicking the tray icon.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display Tray icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use platform specific notification service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will use try to use platform specific notification
+service when such exists. Change requires restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>UpdateWatermarkOperation</name>
     <message>
@@ -1320,4 +1614,27 @@ When omitted, everything is copied.</source>
         <translation>Felhasználó:</translation>
     </message>
 </context>
+<context>
+    <name>WatermarkSettings</name>
+    <message>
+        <source>Watermark Image</source>
+        <translation type="unfinished">Vízjel-kép</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation type="unfinished">Frissítés</translation>
+    </message>
+    <message>
+        <source>Rotate Watermark</source>
+        <translation type="unfinished">Vízjel forgatása</translation>
+    </message>
+    <message>
+        <source>When enabled, Watermark will be added with a rotation of 45°</source>
+        <translation type="unfinished">Ha engedélyezve van, a vízjel 45°-kal elforgatva lesz hozzáadva a képhez</translation>
+    </message>
+    <message>
+        <source>Watermark Settings</source>
+        <translation>Vízjel beállítások</translation>
+    </message>
+</context>
 </TS>
