@@ -27,24 +27,94 @@
         <source>Donate</source>
         <translation>寄付</translation>
     </message>
+    <message>
+        <source>Contact</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AboutTab</name>
-    <message>
-        <source>Screenshot Tool</source>
-        <translation>スクリーンショットツール</translation>
-    </message>
     <message>
         <source>License: </source>
         <translation>ライセンス: </translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>バグ報告は </translation>
+        <source>Screenshot and Annotation Tool</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionSettingTab</name>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> で受け付けています。</translation>
+        <source>Shortcut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished">消去</translation>
+    </message>
+    <message>
+        <source>Take Capture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include Cursor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>s</source>
+        <translation type="unfinished">秒</translation>
+    </message>
+    <message>
+        <source>Capture Mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show image in Pin Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy image to Clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open image parent directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Main Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionsSettings</name>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished">追加</translation>
+    </message>
+    <message>
+        <source>Actions Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Action</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -60,14 +130,6 @@
 </context>
 <context>
     <name>AnnotationSettings</name>
-    <message>
-        <source>Paint Item Shadows</source>
-        <translation>アイテムの影を描画する</translation>
-    </message>
-    <message>
-        <source>When enabled, paint items cast shadows.</source>
-        <translation>有効にすると各アイテムに影が付きます。</translation>
-    </message>
     <message>
         <source>Smooth Painter Paths</source>
         <translation>パスの描画を滑らかにする</translation>
@@ -89,50 +151,6 @@ make them more smooth.</source>
         <translation>滑らか係数を大きくするとペンツールやマーカー
 ツールの精度が落ち、より一層滑らかになります。</translation>
     </message>
-    <message>
-        <source>Text Font</source>
-        <translation>テキストのフォント</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Text Paint Item.</source>
-        <translation>テキスト描画ツール用のフォントを設定します。</translation>
-    </message>
-    <message>
-        <source>Bold</source>
-        <translation>太字</translation>
-    </message>
-    <message>
-        <source>Italic</source>
-        <translation>斜体</translation>
-    </message>
-    <message>
-        <source>Underline</source>
-        <translation>下線</translation>
-    </message>
-    <message>
-        <source>Numbering Font</source>
-        <translation>番号のフォント</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Numbering Paint Item.</source>
-        <translation>番号描画ツール用のフォントを設定します。</translation>
-    </message>
-    <message>
-        <source>Watermark Image</source>
-        <translation>ウォーターマーク画像</translation>
-    </message>
-    <message>
-        <source>Update</source>
-        <translation>更新</translation>
-    </message>
-    <message>
-        <source>Rotate Watermark</source>
-        <translation>ウォーターマークを傾ける</translation>
-    </message>
-    <message>
-        <source>When enabled, Watermark will be added with a rotation of 45°</source>
-        <translation>有効にするとウォーターマークが 45° 傾いた状態になります</translation>
-    </message>
     <message>
         <source>Annotator Settings</source>
         <translation>注釈設定</translation>
@@ -143,6 +161,34 @@ make them more smooth.</source>
     </message>
     <message>
         <source>Switch to Select Tool after drawing Item</source>
+        <translation>アイテムを描画したら選択ツールに切り替える</translation>
+    </message>
+    <message>
+        <source>Number Tool Seed change updates all Number Items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disabling this option causes changes of the number tool
+seed to affect only new items but not existing items.
+Disabling this option allows having duplicate numbers.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Canvas Color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Canvas background color for annotation area.
+Changing color affects only new annotation areas.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Item after drawing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>With this option enabled the item gets selected after
+being created, allowing changing settings.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -152,25 +198,6 @@ make them more smooth.</source>
         <source>Capture screenshot at startup with default mode</source>
         <translation>起動時に既定のモードでスクリーンショットを撮る</translation>
     </message>
-    <message>
-        <source>Use Tray Icon</source>
-        <translation>トレイアイコンを使用する</translation>
-    </message>
-    <message>
-        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
-Change requires restart.</source>
-        <translation>有効にすると、タスクバーにトレイアイコンを追加します 
-(OS のウィンドウマネージャーがサポートしている場合)。
-変更には再起動が必要です。</translation>
-    </message>
-    <message>
-        <source>Minimize to Tray</source>
-        <translation>最小化したらトレイに格納する</translation>
-    </message>
-    <message>
-        <source>Close to Tray</source>
-        <translation>ウィンドウを閉じたらトレイに格納する</translation>
-    </message>
     <message>
         <source>Application Style</source>
         <translation>アプリケーションスタイル</translation>
@@ -189,10 +216,6 @@ Change requires ksnip restart to take effect.</source>
         <source>Automatically copy new captures to clipboard</source>
         <translation>自動的に新しいキャプチャーをクリップボードにコピーする</translation>
     </message>
-    <message>
-        <source>Auto Hide Tabs</source>
-        <translation>タブを自動で隠す</translation>
-    </message>
     <message>
         <source>Use Tabs</source>
         <translation>タブを使用する</translation>
@@ -205,10 +228,6 @@ Change requires ksnip restart to take effect.</source>
         <source>Run ksnip as single instance</source>
         <translation>ksnip をシングルインスタンスとして実行する</translation>
     </message>
-    <message>
-        <source>Start Minimized to Tray</source>
-        <translation>トレイに最小化して起動する</translation>
-    </message>
     <message>
         <source>Hide Tabbar when only one Tab is used.</source>
         <translation>タブが一つの時はタブバーを隠します。</translation>
@@ -225,15 +244,32 @@ a new start of all instances.</source>
     </message>
     <message>
         <source>Remember Main Window position on move and load on startup</source>
+        <translation>メインウィンドウの位置を記憶して起動時に読み込む</translation>
+    </message>
+    <message>
+        <source>Auto hide Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>On startup hide Toolbar and Annotation Settings.
+Docks visibility can be toggled with the Tab Key.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto resize to content</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically resize Main Window to fit content image.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>AuthorTab</name>
-    <message>
-        <source>The Author:</source>
-        <translation>作者:</translation>
-    </message>
     <message>
         <source>Contributors:</source>
         <translation>貢献者:</translation>
@@ -267,7 +303,7 @@ a new start of all instances.</source>
         <translation>Snap と Flatpak のサポート</translation>
     </message>
     <message>
-        <source>Feature Implementation</source>
+        <source>The Authors:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -290,63 +326,85 @@ Do you want to save it?</source>
         <source>New</source>
         <translation>新規</translation>
     </message>
-    <message>
-        <source>Rectangular Area</source>
-        <translation>選択範囲</translation>
-    </message>
     <message>
         <source>Draw a rectangular area with your mouse</source>
         <translation>マウスで四角く選択します</translation>
     </message>
-    <message>
-        <source>Last Rectangular Area</source>
-        <translation>最近の選択範囲</translation>
-    </message>
     <message>
         <source>Capture a screenshot of the last selected rectangular area</source>
         <translation>最近選択した範囲のスクリーンショットをキャプチャーします</translation>
     </message>
-    <message>
-        <source>Full Screen (All Monitors)</source>
-        <translation>全画面 (すべてのモニター)</translation>
-    </message>
     <message>
         <source>Capture full screen including all monitors</source>
         <translation>すべてのモニターの全画面をキャプチャーします</translation>
     </message>
-    <message>
-        <source>Current Screen</source>
-        <translation>現在の画面</translation>
-    </message>
     <message>
         <source>Capture screen where the mouse is located</source>
         <translation>マウスカーソルがある画面をキャプチャーします</translation>
     </message>
-    <message>
-        <source>Active Window</source>
-        <translation>アクティブウィンドウ</translation>
-    </message>
     <message>
         <source>Capture window that currently has focus</source>
         <translation>現在フォーカスがあるウィンドウをキャプチャーします</translation>
     </message>
-    <message>
-        <source>Window Under Cursor</source>
-        <translation>カーソルがあるウィンドウ</translation>
-    </message>
     <message>
         <source>Capture that is currently under the mouse cursor</source>
         <translation>現在マウスカーソルがあるウィンドウをキャプチャーします</translation>
     </message>
-    <message>
-        <source>Screenshot Portal</source>
-        <translation>Screenshot Portal</translation>
-    </message>
     <message>
         <source>Uses the screenshot Portal for taking screenshot</source>
         <translation>スクリーンショットの取得に Screenshot Portal を使用します</translation>
     </message>
 </context>
+<context>
+    <name>ContactTab</name>
+    <message>
+        <source>Community</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>please join our </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> server.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bug Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please use </source>
+        <translation type="unfinished">バグ報告は </translation>
+    </message>
+    <message>
+        <source> to report bugs.</source>
+        <translation type="unfinished"> で受け付けています。</translation>
+    </message>
+</context>
+<context>
+    <name>CopyAsDataUriOperation</name>
+    <message>
+        <source>Failed to copy to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to copy to clipboard as base64 encoded image.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard as base64 encoded image.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DeleteImageOperation</name>
     <message>
@@ -391,6 +449,44 @@ Do you want to continue?</source>
         <translation>開発者をビールやコーヒーで支援していただける場合は</translation>
     </message>
 </context>
+<context>
+    <name>EmptyActionSettingTab</name>
+    <message>
+        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>EnumTranslator</name>
+    <message>
+        <source>Rectangular Area</source>
+        <translation type="unfinished">選択範囲</translation>
+    </message>
+    <message>
+        <source>Last Rectangular Area</source>
+        <translation type="unfinished">最近の選択範囲</translation>
+    </message>
+    <message>
+        <source>Full Screen (All Monitors)</source>
+        <translation type="unfinished">全画面 (すべてのモニター)</translation>
+    </message>
+    <message>
+        <source>Current Screen</source>
+        <translation type="unfinished">現在の画面</translation>
+    </message>
+    <message>
+        <source>Active Window</source>
+        <translation type="unfinished">アクティブウィンドウ</translation>
+    </message>
+    <message>
+        <source>Window Under Cursor</source>
+        <translation type="unfinished">カーソルがあるウィンドウ</translation>
+    </message>
+    <message>
+        <source>Screenshot Portal</source>
+        <translation type="unfinished">Screenshot Portal</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
@@ -456,10 +552,6 @@ Do you want to continue?</source>
         <source>Enable Global HotKeys</source>
         <translation>グローバルホットキーを有効にする</translation>
     </message>
-    <message>
-        <source>HotKeys are currently supported only for Windows and X11</source>
-        <translation>現在 Windows と X11 のみホットキーをサポートしています</translation>
-    </message>
     <message>
         <source>Capture Rect Area</source>
         <translation>選択範囲をキャプチャー</translation>
@@ -496,6 +588,11 @@ Do you want to continue?</source>
         <source>Capture using Portal</source>
         <translation>Portal を使用してキャプチャー</translation>
     </message>
+    <message>
+        <source>HotKeys are currently supported only for Windows and X11.
+Disabling this option makes also the action shortcuts ksnip only.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImageGrabberSettings</name>
@@ -509,66 +606,10 @@ screenshots.</source>
         <translation>スクリーンショットにマウスカーソルを
 表示させたい場合は有効にしてください。</translation>
     </message>
-    <message>
-        <source>Freeze Image while snipping</source>
-        <translation>範囲選択画面で画像を固定する</translation>
-    </message>
-    <message>
-        <source>Show magnifying glass on snipping area</source>
-        <translation>範囲選択画面で拡大鏡を表示する</translation>
-    </message>
-    <message>
-        <source>Show a magnifying glass which zooms into
-the background image. This option only works
-with &apos;Freeze Image while snipping&apos; enabled.</source>
-        <translation>背景画像を拡大する拡大鏡を表示します。
-このオプションは「範囲選択画面で画像を
-固定する」が有効な場合のみ動作します。</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area rulers</source>
-        <translation>範囲選択画面でルーラーを表示する</translation>
-    </message>
-    <message>
-        <source>Horizontal and vertical lines going from
-desktop edges to cursor on snipping area.</source>
-        <translation>マウスカーソルから画面端まで
-横線と縦線を表示します。</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area position and size info</source>
-        <translation>範囲選択画面でカーソル位置情報や選択サイズ情報を表示する</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor color</source>
-        <translation>範囲選択カーソルの色</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor thickness</source>
-        <translation>範囲選択カーソルの太さ</translation>
-    </message>
     <message>
         <source>Image Grabber</source>
         <translation>画像取得</translation>
     </message>
-    <message>
-        <source>When enabled will freeze the background while
-selecting a rectangular region. It also changes
-the behavior of delayed screenshots, with this
-option enabled the delay happens before the
-snipping area is shown and with the option disabled
-the delay happens after the snipping area is shown.
-This feature is always disabled for Wayland and always
-enabled for MacOs.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When left mouse button is not pressed the position
-is shown, when the mouse button is pressed,
-the size of the select area is shown left
-and above from the captured area.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Force Generic Wayland Screenshot</source>
         <translation type="unfinished"></translation>
@@ -595,38 +636,19 @@ Change in this option require a ksnip restart.</source>
     </message>
     <message>
         <source>Show Main Window after capturing screenshot</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show Main Window after capturing a new screenshot
-when the Main Window was hidden or minimized.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Allow resizing rect area selection</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When enabled will, after selecting a rect
-area, allow resizing the selection. When
-done resizing the selection can be confirmed
-by pressing return.</source>
-        <translation type="unfinished"></translation>
+        <translation>スクリーンショット撮影後にメインウィンドウを表示する</translation>
     </message>
     <message>
         <source>Hide Main Window during screenshot</source>
-        <translation type="unfinished"></translation>
+        <translation>スクリーンショット撮影中はメインウィンドウを隠す</translation>
     </message>
     <message>
         <source>Hide Main Window when capturing a new screenshot.</source>
-        <translation type="unfinished"></translation>
+        <translation>新しいスクリーンショットを撮る時にメインウィンドウを非表示にします。</translation>
     </message>
     <message>
-        <source>Sets the color of the snipping area cursor.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sets the thickness of the snipping area cursor.</source>
+        <source>Show Main Window after capturing a new screenshot
+when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -722,10 +744,6 @@ by pressing return.</source>
         <source>Waiting for imgur.com…</source>
         <translation>imgur.com を待っています…</translation>
     </message>
-    <message>
-        <source>Username:</source>
-        <translation>ユーザー名:</translation>
-    </message>
     <message>
         <source>Imgur.com token successfully updated.</source>
         <translation>Imgur.com トークンの更新に成功しました。</translation>
@@ -748,6 +766,21 @@ Changing requires restart.</source>
         <translation>Imgur との通信時に使用するベース URL です。
 変更には再起動が必要です。</translation>
     </message>
+    <message>
+        <source>Clear Token</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoadImageFromFileOperation</name>
+    <message>
+        <source>Unable to open image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open image from path %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainToolBar</name>
@@ -836,10 +869,6 @@ and capturing screenshot.</source>
         <source>Scale</source>
         <translation>拡大縮小</translation>
     </message>
-    <message>
-        <source>Scale Screen Capture</source>
-        <translation>スクリーンキャプチャーを拡大または縮小します</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>ウォーターマークを追加</translation>
@@ -896,10 +925,6 @@ and capturing screenshot.</source>
         <source>Paste Embedded</source>
         <translation>貼り付け (埋め込み)</translation>
     </message>
-    <message>
-        <source>Upload capture to external source</source>
-        <translation>キャプチャーを外部ソースにアップロードします</translation>
-    </message>
     <message>
         <source>Pin</source>
         <translation>ピン留め</translation>
@@ -930,10 +955,50 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Rename</source>
-        <translation type="unfinished"></translation>
+        <translation>名前を変更</translation>
     </message>
     <message>
         <source>Open Images</source>
+        <translation>画像を開く</translation>
+    </message>
+    <message>
+        <source>Show Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy as data URI</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open &amp;Recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify Canvas</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload triggerCapture to external source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy triggerCapture to system clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate Image</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -965,7 +1030,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Rename</source>
-        <translation type="unfinished"></translation>
+        <translation>名前を変更</translation>
     </message>
 </context>
 <context>
@@ -1001,27 +1066,27 @@ and capturing screenshot.</source>
     <name>RenameOperation</name>
     <message>
         <source>Image Renamed</source>
-        <translation type="unfinished"></translation>
+        <translation>画像の名前を変更しました</translation>
     </message>
     <message>
         <source>Successfully renamed image to </source>
-        <translation type="unfinished"></translation>
+        <translation>次の名前に変更しました: </translation>
     </message>
     <message>
         <source>Image Rename Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>画像の名前を変更できませんでした</translation>
     </message>
     <message>
         <source>Failed to rename image to </source>
-        <translation type="unfinished"></translation>
+        <translation>次の名前に変更できませんでした: </translation>
     </message>
     <message>
         <source>Rename image</source>
-        <translation type="unfinished"></translation>
+        <translation>画像の名前を変更</translation>
     </message>
     <message>
         <source>New filename:</source>
-        <translation type="unfinished"></translation>
+        <translation>新しいファイル名:</translation>
     </message>
 </context>
 <context>
@@ -1219,6 +1284,181 @@ When omitted, everything is copied.</source>
         <source>Stickers</source>
         <translation>ステッカー</translation>
     </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Watermark</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaResizerInfoText</name>
+    <message>
+        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys to move the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSelectorInfoText</name>
+    <message>
+        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to resize selection after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Operation will be canceled after 60 sec when no selection made.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSettings</name>
+    <message>
+        <source>Freeze Image while snipping</source>
+        <translation type="unfinished">範囲選択画面で画像を固定する</translation>
+    </message>
+    <message>
+        <source>When enabled will freeze the background while
+selecting a rectangular region. It also changes
+the behavior of delayed screenshots, with this
+option enabled the delay happens before the
+snipping area is shown and with the option disabled
+the delay happens after the snipping area is shown.
+This feature is always disabled for Wayland and always
+enabled for MacOs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show magnifying glass on snipping area</source>
+        <translation type="unfinished">範囲選択画面で拡大鏡を表示する</translation>
+    </message>
+    <message>
+        <source>Show a magnifying glass which zooms into
+the background image. This option only works
+with &apos;Freeze Image while snipping&apos; enabled.</source>
+        <translation type="unfinished">背景画像を拡大する拡大鏡を表示します。
+このオプションは「範囲選択画面で画像を
+固定する」が有効な場合のみ動作します。</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area rulers</source>
+        <translation type="unfinished">範囲選択画面でルーラーを表示する</translation>
+    </message>
+    <message>
+        <source>Horizontal and vertical lines going from
+desktop edges to cursor on snipping area.</source>
+        <translation type="unfinished">マウスカーソルから画面端まで
+横線と縦線を表示します。</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area position and size info</source>
+        <translation type="unfinished">範囲選択画面でカーソル位置情報や選択サイズ情報を表示する</translation>
+    </message>
+    <message>
+        <source>When left mouse button is not pressed the position
+is shown, when the mouse button is pressed,
+the size of the select area is shown left
+and above from the captured area.</source>
+        <translation type="unfinished">マウスの左ボタンを押していない場合は
+カーソルの位置情報が表示され、押して
+いる場合は選択範囲の長さが表示されま
+す。</translation>
+    </message>
+    <message>
+        <source>Allow resizing rect area selection by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will, after selecting a rect
+area, allow resizing the selection. When
+done resizing the selection can be confirmed
+by pressing return.</source>
+        <translation type="unfinished">有効にすると、範囲選択後にそのサイズを変更
+できるようになります。
+サイズ変更後に Return キーを押すと確定します。</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area info text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor color</source>
+        <translation type="unfinished">範囲選択カーソルの色</translation>
+    </message>
+    <message>
+        <source>Sets the color of the snipping area cursor.</source>
+        <translation type="unfinished">範囲選択カーソルの色を設定します。</translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor thickness</source>
+        <translation type="unfinished">範囲選択カーソルの太さ</translation>
+    </message>
+    <message>
+        <source>Sets the thickness of the snipping area cursor.</source>
+        <translation type="unfinished">範囲選択カーソルの太さを設定します。</translation>
+    </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area adorner color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sets the color of all adorner elements
+on the snipping area.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area Transparency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Alpha for not selected region on snipping area.
+Smaller number is more transparent.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
@@ -1252,7 +1492,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>Add Stickers</source>
-        <translation type="unfinished"></translation>
+        <translation>ステッカーを追加</translation>
     </message>
 </context>
 <context>
@@ -1262,6 +1502,65 @@ When omitted, everything is copied.</source>
         <translation>エディターを表示</translation>
     </message>
 </context>
+<context>
+    <name>TrayIconSettings</name>
+    <message>
+        <source>Use Tray Icon</source>
+        <translation type="unfinished">トレイアイコンを使用する</translation>
+    </message>
+    <message>
+        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
+Change requires restart.</source>
+        <translation type="unfinished">有効にすると、タスクバーにトレイアイコンを追加します 
+(OS のウィンドウマネージャーがサポートしている場合)。
+変更には再起動が必要です。</translation>
+    </message>
+    <message>
+        <source>Minimize to Tray</source>
+        <translation type="unfinished">最小化したらトレイに格納する</translation>
+    </message>
+    <message>
+        <source>Start Minimized to Tray</source>
+        <translation type="unfinished">トレイに最小化して起動する</translation>
+    </message>
+    <message>
+        <source>Close to Tray</source>
+        <translation type="unfinished">ウィンドウを閉じたらトレイに格納する</translation>
+    </message>
+    <message>
+        <source>Show Editor</source>
+        <translation type="unfinished">エディターを表示</translation>
+    </message>
+    <message>
+        <source>Capture</source>
+        <translation type="unfinished">キャプチャー</translation>
+    </message>
+    <message>
+        <source>Default Tray Icon action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Action that is triggered by left clicking the tray icon.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display Tray icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use platform specific notification service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will use try to use platform specific notification
+service when such exists. Change requires restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>UpdateWatermarkOperation</name>
     <message>
@@ -1334,4 +1633,27 @@ When omitted, everything is copied.</source>
         <translation>使用:</translation>
     </message>
 </context>
+<context>
+    <name>WatermarkSettings</name>
+    <message>
+        <source>Watermark Image</source>
+        <translation type="unfinished">ウォーターマーク画像</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation type="unfinished">更新</translation>
+    </message>
+    <message>
+        <source>Rotate Watermark</source>
+        <translation type="unfinished">ウォーターマークを傾ける</translation>
+    </message>
+    <message>
+        <source>When enabled, Watermark will be added with a rotation of 45°</source>
+        <translation type="unfinished">有効にするとウォーターマークが 45° 傾いた状態になります</translation>
+    </message>
+    <message>
+        <source>Watermark Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
