@@ -27,24 +27,94 @@
         <source>Donate</source>
         <translation>Doner</translation>
     </message>
+    <message>
+        <source>Contact</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AboutTab</name>
-    <message>
-        <source>Screenshot Tool</source>
-        <translation type="unfinished">Skjermavbildningsverktøy</translation>
-    </message>
     <message>
         <source>License: </source>
         <translation type="unfinished">Lisens: </translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation type="unfinished">Bruk </translation>
+        <source>Screenshot and Annotation Tool</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionSettingTab</name>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation type="unfinished"> for å innrapportere feil.</translation>
+        <source>Shortcut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished">Tøm</translation>
+    </message>
+    <message>
+        <source>Take Capture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include Cursor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>s</source>
+        <translation type="unfinished">s</translation>
+    </message>
+    <message>
+        <source>Capture Mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show image in Pin Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy image to Clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open image parent directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Main Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionsSettings</name>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished">Legg til</translation>
+    </message>
+    <message>
+        <source>Actions Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Action</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -60,14 +130,6 @@
 </context>
 <context>
     <name>AnnotationSettings</name>
-    <message>
-        <source>Paint Item Shadows</source>
-        <translation type="unfinished">Tegn elementskygger</translation>
-    </message>
-    <message>
-        <source>When enabled, paint items cast shadows.</source>
-        <translation type="unfinished">Tegner kastskygger fra elementer når påslått.</translation>
-    </message>
     <message>
         <source>Smooth Painter Paths</source>
         <translation type="unfinished">Myk ut tegningsstrøk</translation>
@@ -90,50 +152,6 @@ make them more smooth.</source>
 nøyaktigheten for penn og markør, men
 vil gjøre dem mykere.</translation>
     </message>
-    <message>
-        <source>Text Font</source>
-        <translation type="unfinished">Tekstskrift</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Text Paint Item.</source>
-        <translation type="unfinished">Setter skrift for teksttegningselementet.</translation>
-    </message>
-    <message>
-        <source>Bold</source>
-        <translation type="unfinished">Fet</translation>
-    </message>
-    <message>
-        <source>Italic</source>
-        <translation type="unfinished">Kursiv</translation>
-    </message>
-    <message>
-        <source>Underline</source>
-        <translation type="unfinished">Understrek</translation>
-    </message>
-    <message>
-        <source>Numbering Font</source>
-        <translation type="unfinished">Skriftart for nummer</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Numbering Paint Item.</source>
-        <translation type="unfinished">Setter skriftarten for nummertegningselementet.</translation>
-    </message>
-    <message>
-        <source>Watermark Image</source>
-        <translation>Vannmerkingsbilde</translation>
-    </message>
-    <message>
-        <source>Update</source>
-        <translation>Oppdater</translation>
-    </message>
-    <message>
-        <source>Rotate Watermark</source>
-        <translation>Roter vannmerke</translation>
-    </message>
-    <message>
-        <source>When enabled, Watermark will be added with a rotation of 45°</source>
-        <translation>Legger til vannmere rotert 45°</translation>
-    </message>
     <message>
         <source>Annotator Settings</source>
         <translation type="unfinished">Undertekstingsinnstillinger</translation>
@@ -146,6 +164,34 @@ vil gjøre dem mykere.</translation>
         <source>Switch to Select Tool after drawing Item</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number Tool Seed change updates all Number Items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disabling this option causes changes of the number tool
+seed to affect only new items but not existing items.
+Disabling this option allows having duplicate numbers.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Canvas Color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Canvas background color for annotation area.
+Changing color affects only new annotation areas.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Item after drawing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>With this option enabled the item gets selected after
+being created, allowing changing settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -167,31 +213,10 @@ grensesnittet. Endringer krever omstart av ksnip.</translation>
         <source>Application Settings</source>
         <translation type="unfinished">Programinnstillinger</translation>
     </message>
-    <message>
-        <source>Use Tray Icon</source>
-        <translation>Bruk systemkurvsikon</translation>
-    </message>
-    <message>
-        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
-Change requires restart.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Minimize to Tray</source>
-        <translation>Minimer til systemkurven</translation>
-    </message>
-    <message>
-        <source>Close to Tray</source>
-        <translation>Lukk til systemkurven</translation>
-    </message>
     <message>
         <source>Automatically copy new captures to clipboard</source>
         <translation>Kopier nye avbildninger til utklippstavle automatisk</translation>
     </message>
-    <message>
-        <source>Auto Hide Tabs</source>
-        <translation>Skjul faner automatisk</translation>
-    </message>
     <message>
         <source>Use Tabs</source>
         <translation>Bruk faner</translation>
@@ -204,10 +229,6 @@ Change requires restart.</source>
         <source>Run ksnip as single instance</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Start Minimized to Tray</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Hide Tabbar when only one Tab is used.</source>
         <translation type="unfinished"></translation>
@@ -223,13 +244,30 @@ a new start of all instances.</source>
         <source>Remember Main Window position on move and load on startup</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Auto hide Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>On startup hide Toolbar and Annotation Settings.
+Docks visibility can be toggled with the Tab Key.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto resize to content</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically resize Main Window to fit content image.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
-    <message>
-        <source>The Author:</source>
-        <translation type="unfinished">Utvikleren:</translation>
-    </message>
     <message>
         <source>Contributors:</source>
         <translation type="unfinished">Bidragsytere:</translation>
@@ -263,7 +301,7 @@ a new start of all instances.</source>
         <translation>Snap og Flatpak -støtte</translation>
     </message>
     <message>
-        <source>Feature Implementation</source>
+        <source>The Authors:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -285,60 +323,82 @@ Do you want to save it?</source>
         <source>New</source>
         <translation>Ny</translation>
     </message>
-    <message>
-        <source>Rectangular Area</source>
-        <translation>Rektangulært område</translation>
-    </message>
     <message>
         <source>Draw a rectangular area with your mouse</source>
         <translation>Tegn et rektangulært område med musen din</translation>
     </message>
-    <message>
-        <source>Full Screen (All Monitors)</source>
-        <translation>Fullskjermsvisning (alle skjermer)</translation>
-    </message>
     <message>
         <source>Capture full screen including all monitors</source>
         <translation>Avbild hele skjermen på tvers av alle monitorer</translation>
     </message>
-    <message>
-        <source>Current Screen</source>
-        <translation>Nåværende skjerm</translation>
-    </message>
     <message>
         <source>Capture screen where the mouse is located</source>
         <translation type="unfinished">Avbild skjerm der pekeren befinner seg</translation>
     </message>
-    <message>
-        <source>Active Window</source>
-        <translation>Aktivt vindu</translation>
-    </message>
     <message>
         <source>Capture window that currently has focus</source>
         <translation>Avbild vindu som er i fokus</translation>
     </message>
-    <message>
-        <source>Window Under Cursor</source>
-        <translation>Vindu under peker</translation>
-    </message>
     <message>
         <source>Capture that is currently under the mouse cursor</source>
         <translation type="unfinished">Avbild det som er under musepekeren</translation>
     </message>
-    <message>
-        <source>Last Rectangular Area</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Capture a screenshot of the last selected rectangular area</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Screenshot Portal</source>
+        <source>Uses the screenshot Portal for taking screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ContactTab</name>
+    <message>
+        <source>Community</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Uses the screenshot Portal for taking screenshot</source>
+        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>please join our </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> server.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bug Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please use </source>
+        <translation type="unfinished">Bruk </translation>
+    </message>
+    <message>
+        <source> to report bugs.</source>
+        <translation type="unfinished"> for å innrapportere feil.</translation>
+    </message>
+</context>
+<context>
+    <name>CopyAsDataUriOperation</name>
+    <message>
+        <source>Failed to copy to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to copy to clipboard as base64 encoded image.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard as base64 encoded image.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -386,6 +446,44 @@ Do you want to continue?</source>
         <translation>Hvis du ønsker å hjelpe, eller bare&lt;br/&gt;vil verdsette arbeidet som gjøres&lt;br/&gt;ved å spandere øl eller kaffe på utviklerne, kan du gjøre dette</translation>
     </message>
 </context>
+<context>
+    <name>EmptyActionSettingTab</name>
+    <message>
+        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>EnumTranslator</name>
+    <message>
+        <source>Rectangular Area</source>
+        <translation type="unfinished">Rektangulært område</translation>
+    </message>
+    <message>
+        <source>Last Rectangular Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Full Screen (All Monitors)</source>
+        <translation type="unfinished">Fullskjermsvisning (alle skjermer)</translation>
+    </message>
+    <message>
+        <source>Current Screen</source>
+        <translation type="unfinished">Nåværende skjerm</translation>
+    </message>
+    <message>
+        <source>Active Window</source>
+        <translation type="unfinished">Aktivt vindu</translation>
+    </message>
+    <message>
+        <source>Window Under Cursor</source>
+        <translation type="unfinished">Vindu under peker</translation>
+    </message>
+    <message>
+        <source>Screenshot Portal</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
@@ -475,10 +573,6 @@ Do you want to continue?</source>
         <source>Global HotKeys</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>HotKeys are currently supported only for Windows and X11</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Capture Last Rect Area</source>
         <translation type="unfinished"></translation>
@@ -491,6 +585,11 @@ Do you want to continue?</source>
         <source>Capture using Portal</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>HotKeys are currently supported only for Windows and X11.
+Disabling this option makes also the action shortcuts ksnip only.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImageGrabberSettings</name>
@@ -504,66 +603,10 @@ screenshots.</source>
         <translation type="unfinished">Hvorvidt pekeren tas med på
 skjermavbildninger.</translation>
     </message>
-    <message>
-        <source>Freeze Image while snipping</source>
-        <translation type="unfinished">Frys bildet under tilpasning</translation>
-    </message>
-    <message>
-        <source>Show magnifying glass on snipping area</source>
-        <translation type="unfinished">Vis forstørrelsesglass i tilpasningsområde</translation>
-    </message>
-    <message>
-        <source>Show a magnifying glass which zooms into
-the background image. This option only works
-with &apos;Freeze Image while snipping&apos; enabled.</source>
-        <translation type="unfinished">Vis et forstørrelsesglass som forstørrer inn i
-bakgrunnsbildet. Dette valget fungerer med
-&quot;Frys bilde under tilpasning&quot; påskrudd.</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area rulers</source>
-        <translation type="unfinished">Vis linjaler for tilpasningsområde</translation>
-    </message>
-    <message>
-        <source>Horizontal and vertical lines going from
-desktop edges to cursor on snipping area.</source>
-        <translation type="unfinished">Vann- og loddrette linjer som går fra
-skrivebordets kanter til pekeren i tilpasningsområdet.</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area position and size info</source>
-        <translation type="unfinished">Vis posisjon og størrelsesinfo for tilpasningsområde</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor color</source>
-        <translation type="unfinished">Pekerfarge for tilpasningsområde</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor thickness</source>
-        <translation type="unfinished">Pekertykkelse for tilpasningsområde</translation>
-    </message>
     <message>
         <source>Image Grabber</source>
         <translation type="unfinished">Bildehenter</translation>
     </message>
-    <message>
-        <source>When enabled will freeze the background while
-selecting a rectangular region. It also changes
-the behavior of delayed screenshots, with this
-option enabled the delay happens before the
-snipping area is shown and with the option disabled
-the delay happens after the snipping area is shown.
-This feature is always disabled for Wayland and always
-enabled for MacOs.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When left mouse button is not pressed the position
-is shown, when the mouse button is pressed,
-the size of the select area is shown left
-and above from the captured area.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Force Generic Wayland Screenshot</source>
         <translation type="unfinished"></translation>
@@ -592,22 +635,6 @@ Change in this option require a ksnip restart.</source>
         <source>Show Main Window after capturing screenshot</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Show Main Window after capturing a new screenshot
-when the Main Window was hidden or minimized.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Allow resizing rect area selection</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When enabled will, after selecting a rect
-area, allow resizing the selection. When
-done resizing the selection can be confirmed
-by pressing return.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Hide Main Window during screenshot</source>
         <translation type="unfinished"></translation>
@@ -617,11 +644,8 @@ by pressing return.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Sets the color of the snipping area cursor.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sets the thickness of the snipping area cursor.</source>
+        <source>Show Main Window after capturing a new screenshot
+when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -713,10 +737,6 @@ by pressing return.</source>
         <source>Waiting for imgur.com…</source>
         <translation>Venter på imgur.com…</translation>
     </message>
-    <message>
-        <source>Username:</source>
-        <translation type="unfinished">Brukernavn:</translation>
-    </message>
     <message>
         <source>Imgur.com token successfully updated.</source>
         <translation type="unfinished">Imgur.com-symbol oppdatert.</translation>
@@ -742,6 +762,21 @@ by pressing return.</source>
 Changing requires restart.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clear Token</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoadImageFromFileOperation</name>
+    <message>
+        <source>Unable to open image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open image from path %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainToolBar</name>
@@ -826,10 +861,6 @@ og avbildning av skjerm.</translation>
         <source>Scale</source>
         <translation>Skaler</translation>
     </message>
-    <message>
-        <source>Scale Screen Capture</source>
-        <translation>Skaler skjermavbildning</translation>
-    </message>
     <message>
         <source>Quit</source>
         <translation>Avslutt</translation>
@@ -890,10 +921,6 @@ og avbildning av skjerm.</translation>
         <source>Paste Embedded</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Upload capture to external source</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Pin</source>
         <translation>Fest</translation>
@@ -930,6 +957,46 @@ og avbildning av skjerm.</translation>
         <source>Open Images</source>
         <translation>Åpne bilder</translation>
     </message>
+    <message>
+        <source>Show Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy as data URI</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open &amp;Recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify Canvas</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload triggerCapture to external source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy triggerCapture to system clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate Image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1205,6 +1272,176 @@ When omitted, everything is copied.</source>
         <source>Stickers</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Watermark</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaResizerInfoText</name>
+    <message>
+        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys to move the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSelectorInfoText</name>
+    <message>
+        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to resize selection after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Operation will be canceled after 60 sec when no selection made.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSettings</name>
+    <message>
+        <source>Freeze Image while snipping</source>
+        <translation type="unfinished">Frys bildet under tilpasning</translation>
+    </message>
+    <message>
+        <source>When enabled will freeze the background while
+selecting a rectangular region. It also changes
+the behavior of delayed screenshots, with this
+option enabled the delay happens before the
+snipping area is shown and with the option disabled
+the delay happens after the snipping area is shown.
+This feature is always disabled for Wayland and always
+enabled for MacOs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show magnifying glass on snipping area</source>
+        <translation type="unfinished">Vis forstørrelsesglass i tilpasningsområde</translation>
+    </message>
+    <message>
+        <source>Show a magnifying glass which zooms into
+the background image. This option only works
+with &apos;Freeze Image while snipping&apos; enabled.</source>
+        <translation type="unfinished">Vis et forstørrelsesglass som forstørrer inn i
+bakgrunnsbildet. Dette valget fungerer med
+&quot;Frys bilde under tilpasning&quot; påskrudd.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area rulers</source>
+        <translation type="unfinished">Vis linjaler for tilpasningsområde</translation>
+    </message>
+    <message>
+        <source>Horizontal and vertical lines going from
+desktop edges to cursor on snipping area.</source>
+        <translation type="unfinished">Vann- og loddrette linjer som går fra
+skrivebordets kanter til pekeren i tilpasningsområdet.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area position and size info</source>
+        <translation type="unfinished">Vis posisjon og størrelsesinfo for tilpasningsområde</translation>
+    </message>
+    <message>
+        <source>When left mouse button is not pressed the position
+is shown, when the mouse button is pressed,
+the size of the select area is shown left
+and above from the captured area.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow resizing rect area selection by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will, after selecting a rect
+area, allow resizing the selection. When
+done resizing the selection can be confirmed
+by pressing return.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Snipping Area info text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor color</source>
+        <translation type="unfinished">Pekerfarge for tilpasningsområde</translation>
+    </message>
+    <message>
+        <source>Sets the color of the snipping area cursor.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor thickness</source>
+        <translation type="unfinished">Pekertykkelse for tilpasningsområde</translation>
+    </message>
+    <message>
+        <source>Sets the thickness of the snipping area cursor.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area adorner color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sets the color of all adorner elements
+on the snipping area.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area Transparency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Alpha for not selected region on snipping area.
+Smaller number is more transparent.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
@@ -1248,6 +1485,63 @@ When omitted, everything is copied.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>TrayIconSettings</name>
+    <message>
+        <source>Use Tray Icon</source>
+        <translation type="unfinished">Bruk systemkurvsikon</translation>
+    </message>
+    <message>
+        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
+Change requires restart.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Minimize to Tray</source>
+        <translation type="unfinished">Minimer til systemkurven</translation>
+    </message>
+    <message>
+        <source>Start Minimized to Tray</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close to Tray</source>
+        <translation type="unfinished">Lukk til systemkurven</translation>
+    </message>
+    <message>
+        <source>Show Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Capture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Tray Icon action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Action that is triggered by left clicking the tray icon.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display Tray icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use platform specific notification service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will use try to use platform specific notification
+service when such exists. Change requires restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>UpdateWatermarkOperation</name>
     <message>
@@ -1320,4 +1614,27 @@ When omitted, everything is copied.</source>
         <translation type="unfinished">Bruker:</translation>
     </message>
 </context>
+<context>
+    <name>WatermarkSettings</name>
+    <message>
+        <source>Watermark Image</source>
+        <translation type="unfinished">Vannmerkingsbilde</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation type="unfinished">Oppdater</translation>
+    </message>
+    <message>
+        <source>Rotate Watermark</source>
+        <translation type="unfinished">Roter vannmerke</translation>
+    </message>
+    <message>
+        <source>When enabled, Watermark will be added with a rotation of 45°</source>
+        <translation type="unfinished">Legger til vannmere rotert 45°</translation>
+    </message>
+    <message>
+        <source>Watermark Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
