@@ -27,24 +27,94 @@
         <source>Donate</source>
         <translation>Donera</translation>
     </message>
+    <message>
+        <source>Contact</source>
+        <translation>Kontakt</translation>
+    </message>
 </context>
 <context>
     <name>AboutTab</name>
-    <message>
-        <source>Screenshot Tool</source>
-        <translation>Skärmklippverktyg</translation>
-    </message>
     <message>
         <source>License: </source>
         <translation>Licens: </translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Använd </translation>
+        <source>Screenshot and Annotation Tool</source>
+        <translation>Skärmklipps- och anteckningsverktyg</translation>
+    </message>
+</context>
+<context>
+    <name>ActionSettingTab</name>
+    <message>
+        <source>Name</source>
+        <translation>Namn</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> för att rapportera fel.</translation>
+        <source>Shortcut</source>
+        <translation>Genväg</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Rensa</translation>
+    </message>
+    <message>
+        <source>Take Capture</source>
+        <translation>Ta skärmklipp</translation>
+    </message>
+    <message>
+        <source>Include Cursor</source>
+        <translation>Inkludera muspekare</translation>
+    </message>
+    <message>
+        <source>Delay</source>
+        <translation>Fördröjning</translation>
+    </message>
+    <message>
+        <source>s</source>
+        <translation>s</translation>
+    </message>
+    <message>
+        <source>Capture Mode</source>
+        <translation>Skärmklippsläge</translation>
+    </message>
+    <message>
+        <source>Show image in Pin Window</source>
+        <translation>Visa bilden i ett fäst fönster</translation>
+    </message>
+    <message>
+        <source>Copy image to Clipboard</source>
+        <translation>Kopiera bilden till urklipp</translation>
+    </message>
+    <message>
+        <source>Upload image</source>
+        <translation>Ladda upp bilden</translation>
+    </message>
+    <message>
+        <source>Open image parent directory</source>
+        <translation>Öppna bildens överordnade mapp</translation>
+    </message>
+    <message>
+        <source>Save image</source>
+        <translation>Spara bilden</translation>
+    </message>
+    <message>
+        <source>Hide Main Window</source>
+        <translation>Dölj huvudfönstret</translation>
+    </message>
+</context>
+<context>
+    <name>ActionsSettings</name>
+    <message>
+        <source>Add</source>
+        <translation>Lägg till</translation>
+    </message>
+    <message>
+        <source>Actions Settings</source>
+        <translation>Åtgärdsinställningar</translation>
+    </message>
+    <message>
+        <source>Action</source>
+        <translation>Åtgärd</translation>
     </message>
 </context>
 <context>
@@ -60,14 +130,6 @@
 </context>
 <context>
     <name>AnnotationSettings</name>
-    <message>
-        <source>Paint Item Shadows</source>
-        <translation>Skugga ritade objekt</translation>
-    </message>
-    <message>
-        <source>When enabled, paint items cast shadows.</source>
-        <translation>Vid aktivering kastar ritade objekt skuggor.</translation>
-    </message>
     <message>
         <source>Smooth Painter Paths</source>
         <translation>Utjämna ritade objekt</translation>
@@ -89,62 +151,50 @@ make them more smooth.</source>
         <translation>Ökad utjämningsfaktor minskar precisionen
 för penna och markör, men gör dem mjukare.</translation>
     </message>
-    <message>
-        <source>Text Font</source>
-        <translation>Teckensnitt för text</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Text Paint Item.</source>
-        <translation>Anger teckensnitt för textobjekt.</translation>
-    </message>
-    <message>
-        <source>Bold</source>
-        <translation>Fet</translation>
-    </message>
-    <message>
-        <source>Italic</source>
-        <translation>Kursiv</translation>
-    </message>
-    <message>
-        <source>Underline</source>
-        <translation>Understruken</translation>
-    </message>
-    <message>
-        <source>Numbering Font</source>
-        <translation>Teckensnitt för numrering</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Numbering Paint Item.</source>
-        <translation>Anger teckensnitt för numrering av ritade objekt.</translation>
-    </message>
-    <message>
-        <source>Watermark Image</source>
-        <translation>Vattenstämpel</translation>
-    </message>
-    <message>
-        <source>Update</source>
-        <translation>Uppdatera</translation>
-    </message>
-    <message>
-        <source>Rotate Watermark</source>
-        <translation>Rotera vattenstämpel</translation>
-    </message>
-    <message>
-        <source>When enabled, Watermark will be added with a rotation of 45°</source>
-        <translation>Vid aktivering, roteras vattenstämpeln 45°</translation>
-    </message>
     <message>
         <source>Annotator Settings</source>
         <translation>Anteckningsinställningar</translation>
     </message>
     <message>
         <source>Remember annotation tool selection and load on startup</source>
-        <translation>Kom ihåg val av anteckningsverktyg och läs in vid uppstart</translation>
+        <translation>Kom ihåg val av ritverktyg och läs in vid uppstart</translation>
     </message>
     <message>
         <source>Switch to Select Tool after drawing Item</source>
         <translation>Växla för att välja verktyg efter att ett objekt ritats</translation>
     </message>
+    <message>
+        <source>Number Tool Seed change updates all Number Items</source>
+        <translation>Ändring i numreringsverktyget uppdaterar alla nummerposter</translation>
+    </message>
+    <message>
+        <source>Disabling this option causes changes of the number tool
+seed to affect only new items but not existing items.
+Disabling this option allows having duplicate numbers.</source>
+        <translation>Inaktivering av det här alternativet innebär att numreringsverktyget
+påverkar endast nya objekt men inte befintliga.
+Inaktivering låter dig använda dubblettnummer.</translation>
+    </message>
+    <message>
+        <source>Canvas Color</source>
+        <translation>Färg på arbetsytan</translation>
+    </message>
+    <message>
+        <source>Default Canvas background color for annotation area.
+Changing color affects only new annotation areas.</source>
+        <translation>Standardfärg på arbetsytan i anteckningsområdet.
+Ändring av färgen påverkar bara nya anteckningsområden.</translation>
+    </message>
+    <message>
+        <source>Select Item after drawing</source>
+        <translation>Markera objekt efter ritning</translation>
+    </message>
+    <message>
+        <source>With this option enabled the item gets selected after
+being created, allowing changing settings.</source>
+        <translation>Med det här alternativet aktiverat, markeras objektet efter
+att det skapats, vilket gör det möjligt att ändra inställningar.</translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -166,32 +216,10 @@ Change requires ksnip restart to take effect.</source>
         <source>Application Settings</source>
         <translation>Programinställningar</translation>
     </message>
-    <message>
-        <source>Use Tray Icon</source>
-        <translation>Använd systemfältsikon</translation>
-    </message>
-    <message>
-        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
-Change requires restart.</source>
-        <translation>Vid aktivering läggs en ikon till i systemfältet, om operativsystemet stödjer det.
-Ändring kräver omstart.</translation>
-    </message>
-    <message>
-        <source>Minimize to Tray</source>
-        <translation>Minimera till systemfältet</translation>
-    </message>
-    <message>
-        <source>Close to Tray</source>
-        <translation>Stäng till systemfältet</translation>
-    </message>
     <message>
         <source>Automatically copy new captures to clipboard</source>
         <translation>Kopiera automatiskt nya skärmklipp till urklipp</translation>
     </message>
-    <message>
-        <source>Auto Hide Tabs</source>
-        <translation>Dölj flikar automatiskt</translation>
-    </message>
     <message>
         <source>Use Tabs</source>
         <translation>Använd flikar</translation>
@@ -204,10 +232,6 @@ Change requires restart.</source>
         <source>Run ksnip as single instance</source>
         <translation>Kör ksnip som enskild instans</translation>
     </message>
-    <message>
-        <source>Start Minimized to Tray</source>
-        <translation>Starta minimerad i systemfältet</translation>
-    </message>
     <message>
         <source>Hide Tabbar when only one Tab is used.</source>
         <translation>Dölj flikfältet när endast en flik används.</translation>
@@ -226,13 +250,31 @@ Om det här alternativet ändras måste alla öppna instanser startas om.</trans
         <source>Remember Main Window position on move and load on startup</source>
         <translation>Kom ihåg huvudfönstrets position vid förflyttning och läs in vid programstart</translation>
     </message>
+    <message>
+        <source>Auto hide Tabs</source>
+        <translation>Dölj flikar automatiskt</translation>
+    </message>
+    <message>
+        <source>Auto hide Docks</source>
+        <translation>Dölj dockor automatiskt</translation>
+    </message>
+    <message>
+        <source>On startup hide Toolbar and Annotation Settings.
+Docks visibility can be toggled with the Tab Key.</source>
+        <translation>Dölj verktygsfält och noteringsinställningar vid uppstart.
+Dockors synlighet kan växlas med Tab-tangenten.</translation>
+    </message>
+    <message>
+        <source>Auto resize to content</source>
+        <translation>Storleksändra automatiskt efter innehåll</translation>
+    </message>
+    <message>
+        <source>Automatically resize Main Window to fit content image.</source>
+        <translation>Ändra automatiskt storleken på huvudfönstret för att passa bilden.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
-    <message>
-        <source>The Author:</source>
-        <translation>Utvecklare:</translation>
-    </message>
     <message>
         <source>Contributors:</source>
         <translation>Medverkande:</translation>
@@ -266,8 +308,8 @@ Om det här alternativet ändras måste alla öppna instanser startas om.</trans
         <translation>Snap- &amp; Flatpak-stöd</translation>
     </message>
     <message>
-        <source>Feature Implementation</source>
-        <translation>Funktionsimplementering</translation>
+        <source>The Authors:</source>
+        <translation>Upphovsmän:</translation>
     </message>
 </context>
 <context>
@@ -289,63 +331,85 @@ Vill du spara det?</translation>
         <source>New</source>
         <translation>Nytt</translation>
     </message>
-    <message>
-        <source>Rectangular Area</source>
-        <translation>Rektangulärt område</translation>
-    </message>
     <message>
         <source>Draw a rectangular area with your mouse</source>
         <translation>Dra upp ett rektangulärt område med musen</translation>
     </message>
-    <message>
-        <source>Full Screen (All Monitors)</source>
-        <translation>Helskärm (Alla skärmar)</translation>
-    </message>
     <message>
         <source>Capture full screen including all monitors</source>
         <translation>Avbildar hela skärmen, samtliga skärmar inkluderade</translation>
     </message>
-    <message>
-        <source>Current Screen</source>
-        <translation>Aktuell skärm</translation>
-    </message>
     <message>
         <source>Capture screen where the mouse is located</source>
         <translation>Avbildar skärmen där muspekaren befinner sig</translation>
     </message>
-    <message>
-        <source>Active Window</source>
-        <translation>Aktivt fönster</translation>
-    </message>
     <message>
         <source>Capture window that currently has focus</source>
         <translation>Avbildar det fönster som har fokus</translation>
     </message>
-    <message>
-        <source>Window Under Cursor</source>
-        <translation>Fönster under muspekaren</translation>
-    </message>
     <message>
         <source>Capture that is currently under the mouse cursor</source>
         <translation>Avbildar fönstret under muspekaren</translation>
     </message>
-    <message>
-        <source>Last Rectangular Area</source>
-        <translation>Tidigare rektangulära område</translation>
-    </message>
     <message>
         <source>Capture a screenshot of the last selected rectangular area</source>
         <translation>Tar ett skärmklipp av senast markerade rektangulära område</translation>
     </message>
-    <message>
-        <source>Screenshot Portal</source>
-        <translation>Skärmklippsportal</translation>
-    </message>
     <message>
         <source>Uses the screenshot Portal for taking screenshot</source>
         <translation>Använder skärmklippsportalen för att ta skärmdump</translation>
     </message>
 </context>
+<context>
+    <name>ContactTab</name>
+    <message>
+        <source>Community</source>
+        <translation>Gemenskap</translation>
+    </message>
+    <message>
+        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
+        <translation>Om du har allmänna frågor, idéer eller bara vill prata om ksnip,</translation>
+    </message>
+    <message>
+        <source>please join our </source>
+        <translation>kan du gå med i vår </translation>
+    </message>
+    <message>
+        <source> server.</source>
+        <translation> server.</translation>
+    </message>
+    <message>
+        <source>Bug Reports</source>
+        <translation>Felrapporter</translation>
+    </message>
+    <message>
+        <source>Please use </source>
+        <translation>Använd </translation>
+    </message>
+    <message>
+        <source> to report bugs.</source>
+        <translation> för att rapportera fel.</translation>
+    </message>
+</context>
+<context>
+    <name>CopyAsDataUriOperation</name>
+    <message>
+        <source>Failed to copy to clipboard</source>
+        <translation>Kunde inte kopiera till urklipp</translation>
+    </message>
+    <message>
+        <source>Failed to copy to clipboard as base64 encoded image.</source>
+        <translation>Kunde inte kopiera till urklipp som base64-kodad bild.</translation>
+    </message>
+    <message>
+        <source>Copied to clipboard</source>
+        <translation>Kopierat till urklipp</translation>
+    </message>
+    <message>
+        <source>Copied to clipboard as base64 encoded image.</source>
+        <translation>Kopierat till urklipp som base64-kodad bild.</translation>
+    </message>
+</context>
 <context>
     <name>DeleteImageOperation</name>
     <message>
@@ -390,6 +454,44 @@ Vill du fortsätta?</translation>
         <translation>Om du vill hjälpa till eller bara&lt;br/&gt;uppskattar det arbete som görs&lt;br/&gt;genom att bjuda utvecklaren på en öl eller kaffe, kan du göra det</translation>
     </message>
 </context>
+<context>
+    <name>EmptyActionSettingTab</name>
+    <message>
+        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
+        <translation>Lägg till nya åtgärder genom att trycka på &quot;Lägg till&quot;.</translation>
+    </message>
+</context>
+<context>
+    <name>EnumTranslator</name>
+    <message>
+        <source>Rectangular Area</source>
+        <translation>Rektangulärt område</translation>
+    </message>
+    <message>
+        <source>Last Rectangular Area</source>
+        <translation>Senaste rektangulära område</translation>
+    </message>
+    <message>
+        <source>Full Screen (All Monitors)</source>
+        <translation>Helskärm (Alla skärmar)</translation>
+    </message>
+    <message>
+        <source>Current Screen</source>
+        <translation>Aktuell skärm</translation>
+    </message>
+    <message>
+        <source>Active Window</source>
+        <translation>Aktivt fönster</translation>
+    </message>
+    <message>
+        <source>Window Under Cursor</source>
+        <translation>Fönster under muspekaren</translation>
+    </message>
+    <message>
+        <source>Screenshot Portal</source>
+        <translation>Skärmklippsportal</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
@@ -479,13 +581,9 @@ Vill du fortsätta?</translation>
         <source>Global HotKeys</source>
         <translation>Systemövergripande snabbtangenter</translation>
     </message>
-    <message>
-        <source>HotKeys are currently supported only for Windows and X11</source>
-        <translation>Snabbtangenter stöds för närvarande bara av Windows och X11</translation>
-    </message>
     <message>
         <source>Capture Last Rect Area</source>
-        <translation>Avbilda tidigare rektangulära område</translation>
+        <translation>Avbilda senaste rektangulära område</translation>
     </message>
     <message>
         <source>Clear</source>
@@ -495,6 +593,12 @@ Vill du fortsätta?</translation>
         <source>Capture using Portal</source>
         <translation>Klipp ut med hjälp av Portal</translation>
     </message>
+    <message>
+        <source>HotKeys are currently supported only for Windows and X11.
+Disabling this option makes also the action shortcuts ksnip only.</source>
+        <translation>Snabbtangenter stöds för närvarande endast av Windows och X11.
+Inaktivering av detta alternativ gör också åtgärdsgenvägar till endast ksnip.</translation>
+    </message>
 </context>
 <context>
     <name>ImageGrabberSettings</name>
@@ -508,76 +612,10 @@ screenshots.</source>
         <translation>Om muspekaren skall vara synlig i
 skärmklipp.</translation>
     </message>
-    <message>
-        <source>Freeze Image while snipping</source>
-        <translation>Frys bilden under områdesklipp</translation>
-    </message>
-    <message>
-        <source>Show magnifying glass on snipping area</source>
-        <translation>Visa förstoringsglas på klippområdet</translation>
-    </message>
-    <message>
-        <source>Show a magnifying glass which zooms into
-the background image. This option only works
-with &apos;Freeze Image while snipping&apos; enabled.</source>
-        <translation>Visa en förstoring som zoomar in i bakgrundsbilden.
-Detta alternativ fungerar endast när
-&quot;Frys bilden under områdesklipp&quot; är aktiverat.</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area rulers</source>
-        <translation>Visa stödlinjer för klippområdet</translation>
-    </message>
-    <message>
-        <source>Horizontal and vertical lines going from
-desktop edges to cursor on snipping area.</source>
-        <translation>Horisontella och vertikala linjer går från
-skrivbordskanten till markören i klippområdet.</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area position and size info</source>
-        <translation>Visa klippområdesplacering och storleksinformation</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor color</source>
-        <translation>Färg på klippområdesmarkören</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor thickness</source>
-        <translation>Tjocklek på klippområdesmarkören</translation>
-    </message>
     <message>
         <source>Image Grabber</source>
         <translation>Områdesklipp</translation>
     </message>
-    <message>
-        <source>When enabled will freeze the background while
-selecting a rectangular region. It also changes
-the behavior of delayed screenshots, with this
-option enabled the delay happens before the
-snipping area is shown and with the option disabled
-the delay happens after the snipping area is shown.
-This feature is always disabled for Wayland and always
-enabled for MacOs.</source>
-        <translation>Vid aktivering fryses bilden medan ett rektangulärt
-område markeras. Det ändrar också beteendet för
-fördröjt skärmklipp. Med detta alternativ aktiverat,
-sker fördröjningen innan klippområdet visas och med
-alternativet avaktiverat, sker fördröjningen efter
-klippområdet visas.
-Denna funktion är alltid inaktiverad för Wayland och
-alltid aktiverad för MacOS.</translation>
-    </message>
-    <message>
-        <source>When left mouse button is not pressed the position
-is shown, when the mouse button is pressed,
-the size of the select area is shown left
-and above from the captured area.</source>
-        <translation>När vänster musknapp inte hålls ner, visas
-positionen. När musknappen hålls ner, visas
-storleken på markerat område till vänster
-och över klippområdet.</translation>
-    </message>
     <message>
         <source>Force Generic Wayland Screenshot</source>
         <translation>Framtvinga inbyggt Wayland-skärmklipp</translation>
@@ -614,26 +652,6 @@ GNOME att använda XDG-DESKTOP-PORTAL-skärmklipp.
         <source>Show Main Window after capturing screenshot</source>
         <translation>Visa huvudfönstret efter utfört skärmklipp</translation>
     </message>
-    <message>
-        <source>Show Main Window after capturing a new screenshot
-when the Main Window was hidden or minimized.</source>
-        <translation>Visa huvudfönstret efter nytt skärmklipp, om
-huvudfönstret var dolt eller minimerat.</translation>
-    </message>
-    <message>
-        <source>Allow resizing rect area selection</source>
-        <translation>Tillåt storleksändring av rektangelmarkering</translation>
-    </message>
-    <message>
-        <source>When enabled will, after selecting a rect
-area, allow resizing the selection. When
-done resizing the selection can be confirmed
-by pressing return.</source>
-        <translation>Vid aktivering kommer en rektangulär
-områdesmarkering att kunna storleksändras.
-När storleksändringen slutförts kan den
-tillämpas genom att trycka Retur.</translation>
-    </message>
     <message>
         <source>Hide Main Window during screenshot</source>
         <translation>Dölj huvudfönstret under skärmklipp</translation>
@@ -643,12 +661,10 @@ tillämpas genom att trycka Retur.</translation>
         <translation>Dölj huvudfönstret när du tar ett nytt skärmklipp.</translation>
     </message>
     <message>
-        <source>Sets the color of the snipping area cursor.</source>
-        <translation>Anger färgen på markören för klippområdet.</translation>
-    </message>
-    <message>
-        <source>Sets the thickness of the snipping area cursor.</source>
-        <translation>Anger tjockleken på klippområdets markör.</translation>
+        <source>Show Main Window after capturing a new screenshot
+when the Main Window was hidden or minimize.</source>
+        <translation>Visa huvudfönstret efter att ha tagit ett nytt skärmklipp,
+när huvudfönstret var dolt eller minimerat.</translation>
     </message>
 </context>
 <context>
@@ -739,10 +755,6 @@ tillämpas genom att trycka Retur.</translation>
         <source>Waiting for imgur.com…</source>
         <translation>Väntar på imgur.com…</translation>
     </message>
-    <message>
-        <source>Username:</source>
-        <translation>Användarnamn:</translation>
-    </message>
     <message>
         <source>Imgur.com token successfully updated.</source>
         <translation>Imgur.com-token uppdaterades.</translation>
@@ -769,6 +781,21 @@ Changing requires restart.</source>
         <translation>Grundläggande URL som används för kommunikation med Imgur.
 Ändring kräver omstart.</translation>
     </message>
+    <message>
+        <source>Clear Token</source>
+        <translation>Rensa token</translation>
+    </message>
+</context>
+<context>
+    <name>LoadImageFromFileOperation</name>
+    <message>
+        <source>Unable to open image</source>
+        <translation>Kan inte öppna bilden</translation>
+    </message>
+    <message>
+        <source>Unable to open image from path %1</source>
+        <translation>Kan inte öppna bild från sökvägen %1</translation>
+    </message>
 </context>
 <context>
     <name>MainToolBar</name>
@@ -853,10 +880,6 @@ och själva skärmklippet.</translation>
         <source>Scale</source>
         <translation>Skala</translation>
     </message>
-    <message>
-        <source>Scale Screen Capture</source>
-        <translation>Skala skärmklippet</translation>
-    </message>
     <message>
         <source>Quit</source>
         <translation>Avsluta</translation>
@@ -917,10 +940,6 @@ och själva skärmklippet.</translation>
         <source>Paste Embedded</source>
         <translation>Klistra in inbäddat</translation>
     </message>
-    <message>
-        <source>Upload capture to external source</source>
-        <translation>Ladda upp skärmklipp till extern källa</translation>
-    </message>
     <message>
         <source>Pin</source>
         <translation>Fäst</translation>
@@ -957,6 +976,46 @@ och själva skärmklippet.</translation>
         <source>Open Images</source>
         <translation>Öppna bilder</translation>
     </message>
+    <message>
+        <source>Show Docks</source>
+        <translation>Visa dockor</translation>
+    </message>
+    <message>
+        <source>Hide Docks</source>
+        <translation>Dölj dockor</translation>
+    </message>
+    <message>
+        <source>Copy as data URI</source>
+        <translation>Kopiera som data-URI</translation>
+    </message>
+    <message>
+        <source>Open &amp;Recent</source>
+        <translation>Öppna &amp;tidigare</translation>
+    </message>
+    <message>
+        <source>Modify Canvas</source>
+        <translation>Ändra arbetsyta</translation>
+    </message>
+    <message>
+        <source>Upload triggerCapture to external source</source>
+        <translation>Ladda upp skärmklipp till extern källa</translation>
+    </message>
+    <message>
+        <source>Copy triggerCapture to system clipboard</source>
+        <translation>Kopiera skärmklipp till systemets urklipp</translation>
+    </message>
+    <message>
+        <source>Scale Image</source>
+        <translation>Skala bild</translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation>Rotera</translation>
+    </message>
+    <message>
+        <source>Rotate Image</source>
+        <translation>Rotera bild</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1132,7 +1191,7 @@ Filnamn kan innehålla följande jokertecken:
     </message>
     <message>
         <source>Save Quality</source>
-        <translation>Spara kvalitet</translation>
+        <translation>Lagringskvalitet</translation>
     </message>
     <message>
         <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
@@ -1240,6 +1299,191 @@ När detta utelämnas kopieras allt.</translation>
         <source>Stickers</source>
         <translation>Dekaler</translation>
     </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation>Klippområde</translation>
+    </message>
+    <message>
+        <source>Tray Icon</source>
+        <translation>Systemfältsikon</translation>
+    </message>
+    <message>
+        <source>Watermark</source>
+        <translation>Vattenstämpel</translation>
+    </message>
+    <message>
+        <source>Actions</source>
+        <translation>Åtgärder</translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaResizerInfoText</name>
+    <message>
+        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
+        <translation>Ändra storlek på markerad rektangel med hjälp av handtagen eller flytta den genom att dra markeringen.</translation>
+    </message>
+    <message>
+        <source>Use arrow keys to move the selection.</source>
+        <translation>Använd piltangenter för att flytta markeringen.</translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
+        <translation>Använd CTRL+piltangenter för att flytta handtaget i vänster överkant.</translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
+        <translation>Använd ALT+piltangenter för att flytta handtaget i höger underkant.</translation>
+    </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
+        <translation>Bekräfta markering genom att trycka RETUR/ENTER eller avbryt med ESC.</translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation>Detta meddelande kan inaktiveras i inställningarna.</translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSelectorInfoText</name>
+    <message>
+        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
+        <translation>Klicka och dra för att markera ett rektangulärt område eller tryck ESC för att avsluta.</translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to resize selection after selecting.</source>
+        <translation>Håll CTRL nedtryckt för att ändra storlek på markeringen.</translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
+        <translation>Håll CTRL nedtryckt för att förhindra storlekändring efter markering.</translation>
+    </message>
+    <message>
+        <source>Operation will be canceled after 60 sec when no selection made.</source>
+        <translation>Åtgärden avbryts efter 60 sekunder, om ingen markering gjorts.</translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation>Detta meddelande kan inaktiveras i inställningarna.</translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSettings</name>
+    <message>
+        <source>Freeze Image while snipping</source>
+        <translation>Frys bilden under klipp</translation>
+    </message>
+    <message>
+        <source>When enabled will freeze the background while
+selecting a rectangular region. It also changes
+the behavior of delayed screenshots, with this
+option enabled the delay happens before the
+snipping area is shown and with the option disabled
+the delay happens after the snipping area is shown.
+This feature is always disabled for Wayland and always
+enabled for MacOs.</source>
+        <translation>Vid aktivering fryses bakgrunden medan ett rektangulärt
+område markeras. Det ändrar också beteendet för
+fördröjt skärmklipp. Med detta alternativ aktiverat,
+sker fördröjningen innan klippområdet visas och med
+alternativet avaktiverat, sker fördröjningen efter
+klippområdet visas.
+Denna funktion är alltid inaktiverad för Wayland och
+alltid aktiverad för MacOS.</translation>
+    </message>
+    <message>
+        <source>Show magnifying glass on snipping area</source>
+        <translation>Visa förstoringsglas på klippområde</translation>
+    </message>
+    <message>
+        <source>Show a magnifying glass which zooms into
+the background image. This option only works
+with &apos;Freeze Image while snipping&apos; enabled.</source>
+        <translation>Visa ett förstoringsglas som zoomar in i bakgrundsbilden.
+Detta alternativ fungerar endast när
+&quot;Frys bilden under klipp&quot; är aktiverat.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area rulers</source>
+        <translation>Visa linjaler på klippområdet</translation>
+    </message>
+    <message>
+        <source>Horizontal and vertical lines going from
+desktop edges to cursor on snipping area.</source>
+        <translation>Horisontella och vertikala linjer går från
+skrivbordskanten till markören i klippområdet.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area position and size info</source>
+        <translation>Visa klippområdesplacering och storleksinformation</translation>
+    </message>
+    <message>
+        <source>When left mouse button is not pressed the position
+is shown, when the mouse button is pressed,
+the size of the select area is shown left
+and above from the captured area.</source>
+        <translation>När vänster musknapp inte hålls ner, visas
+positionen. När musknappen hålls ner, visas
+storleken på markerat område till vänster
+och över klippområdet.</translation>
+    </message>
+    <message>
+        <source>Allow resizing rect area selection by default</source>
+        <translation>Tillåt storleksändring av rektangelområde som standard</translation>
+    </message>
+    <message>
+        <source>When enabled will, after selecting a rect
+area, allow resizing the selection. When
+done resizing the selection can be confirmed
+by pressing return.</source>
+        <translation>Vid aktivering kommer en rektangulär
+områdesmarkering att kunna storleksändras.
+När storleksändringen slutförts kan den
+tillämpas genom att trycka Retur.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area info text</source>
+        <translation>Visa informationstext för klippområde</translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor color</source>
+        <translation>Färg på klippområdesmarkören</translation>
+    </message>
+    <message>
+        <source>Sets the color of the snipping area cursor.</source>
+        <translation>Anger färgen på markören för klippområdet.</translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor thickness</source>
+        <translation>Tjocklek på klippområdesmarkören</translation>
+    </message>
+    <message>
+        <source>Sets the thickness of the snipping area cursor.</source>
+        <translation>Anger tjockleken på klippområdets markör.</translation>
+    </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation>Klippområde</translation>
+    </message>
+    <message>
+        <source>Snipping Area adorner color</source>
+        <translation>Klippområdets prydnadsfärg</translation>
+    </message>
+    <message>
+        <source>Sets the color of all adorner elements
+on the snipping area.</source>
+        <translation>Ställer in färgen på alla prydnadselement
+i klippområdet.</translation>
+    </message>
+    <message>
+        <source>Snipping Area Transparency</source>
+        <translation>Klippområdets transparens</translation>
+    </message>
+    <message>
+        <source>Alpha for not selected region on snipping area.
+Smaller number is more transparent.</source>
+        <translation>Alfa för icke markerad region på klippområdet.
+Lägre siffra är mer transparens.</translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
@@ -1283,6 +1527,65 @@ När detta utelämnas kopieras allt.</translation>
         <translation>Visa redigerare</translation>
     </message>
 </context>
+<context>
+    <name>TrayIconSettings</name>
+    <message>
+        <source>Use Tray Icon</source>
+        <translation>Använd systemfältsikon</translation>
+    </message>
+    <message>
+        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
+Change requires restart.</source>
+        <translation>Vid aktivering läggs en ikon till i systemfältet, om operativsystemet stödjer det.
+Ändring kräver omstart.</translation>
+    </message>
+    <message>
+        <source>Minimize to Tray</source>
+        <translation>Minimera till systemfältet</translation>
+    </message>
+    <message>
+        <source>Start Minimized to Tray</source>
+        <translation>Starta minimerad i systemfältet</translation>
+    </message>
+    <message>
+        <source>Close to Tray</source>
+        <translation>Stäng till systemfältet</translation>
+    </message>
+    <message>
+        <source>Show Editor</source>
+        <translation>Visa redigerare</translation>
+    </message>
+    <message>
+        <source>Capture</source>
+        <translation>Klipp</translation>
+    </message>
+    <message>
+        <source>Default Tray Icon action</source>
+        <translation>Standardåtgärd för systemfältsikon</translation>
+    </message>
+    <message>
+        <source>Default Action that is triggered by left clicking the tray icon.</source>
+        <translation>Standardåtgärd som utlöses genom att vänsterklicka på systemfältsikonen.</translation>
+    </message>
+    <message>
+        <source>Tray Icon Settings</source>
+        <translation>Inställningar för systemfältsikon</translation>
+    </message>
+    <message>
+        <source>Display Tray icon notifications</source>
+        <translation>Visa systemfältsaviseringar</translation>
+    </message>
+    <message>
+        <source>Use platform specific notification service</source>
+        <translation>Använd plattformsspecifik aviseringstjänst</translation>
+    </message>
+    <message>
+        <source>When enabled will use try to use platform specific notification
+service when such exists. Change requires restart to take effect.</source>
+        <translation>Vid aktivering försöker ksnip använda plattformsspecifik avisering
+när sådan finnes. Ändring kräver omstart för att tillämpas.</translation>
+    </message>
+</context>
 <context>
     <name>UpdateWatermarkOperation</name>
     <message>
@@ -1355,4 +1658,27 @@ När detta utelämnas kopieras allt.</translation>
         <translation>Använder:</translation>
     </message>
 </context>
+<context>
+    <name>WatermarkSettings</name>
+    <message>
+        <source>Watermark Image</source>
+        <translation>Vattenstämpel</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation>Uppdatera</translation>
+    </message>
+    <message>
+        <source>Rotate Watermark</source>
+        <translation>Rotera vattenstämpel</translation>
+    </message>
+    <message>
+        <source>When enabled, Watermark will be added with a rotation of 45°</source>
+        <translation>Vid aktivering, roteras vattenstämpeln 45°</translation>
+    </message>
+    <message>
+        <source>Watermark Settings</source>
+        <translation>Vatenstämpelinställningar</translation>
+    </message>
+</context>
 </TS>
