@@ -27,24 +27,94 @@
         <source>Donate</source>
         <translation>Bağış</translation>
     </message>
+    <message>
+        <source>Contact</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AboutTab</name>
-    <message>
-        <source>Screenshot Tool</source>
-        <translation type="unfinished">Ekran Görüntüsü Aracı</translation>
-    </message>
     <message>
         <source>License: </source>
         <translation type="unfinished">Lisans: </translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation type="unfinished">Hata raporlaması için lütfen </translation>
+        <source>Screenshot and Annotation Tool</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionSettingTab</name>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation type="unfinished"> sayfasını kullanın.</translation>
+        <source>Shortcut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished">Temizle</translation>
+    </message>
+    <message>
+        <source>Take Capture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include Cursor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>s</source>
+        <translation type="unfinished">sn</translation>
+    </message>
+    <message>
+        <source>Capture Mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show image in Pin Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy image to Clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open image parent directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Main Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionsSettings</name>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished">Ekle</translation>
+    </message>
+    <message>
+        <source>Actions Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Action</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -60,14 +130,6 @@
 </context>
 <context>
     <name>AnnotationSettings</name>
-    <message>
-        <source>Paint Item Shadows</source>
-        <translation type="unfinished">Boya Öğesi Gölgeleri</translation>
-    </message>
-    <message>
-        <source>When enabled, paint items cast shadows.</source>
-        <translation type="unfinished">Etkinleştirildiğinde, boya öğeleri gölgelidir.</translation>
-    </message>
     <message>
         <source>Smooth Painter Paths</source>
         <translation type="unfinished">Boyama Yollarını Yumuşat</translation>
@@ -90,50 +152,6 @@ make them more smooth.</source>
 işaretleyici için hassasiyeti azaltır ancak
 daha düzgün hale getirir.</translation>
     </message>
-    <message>
-        <source>Text Font</source>
-        <translation type="unfinished">Metin Yazıtipi</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Text Paint Item.</source>
-        <translation type="unfinished">Metin Boyama Öğesi için yazıtipini ayarlar.</translation>
-    </message>
-    <message>
-        <source>Bold</source>
-        <translation type="unfinished">Kalın</translation>
-    </message>
-    <message>
-        <source>Italic</source>
-        <translation type="unfinished">Eğik</translation>
-    </message>
-    <message>
-        <source>Underline</source>
-        <translation type="unfinished">Altı çizili</translation>
-    </message>
-    <message>
-        <source>Numbering Font</source>
-        <translation type="unfinished">Numaralandırma Yazıtipi</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Numbering Paint Item.</source>
-        <translation type="unfinished">Numaralandırma Boyama Öğesi için yazıtipini ayarlar.</translation>
-    </message>
-    <message>
-        <source>Watermark Image</source>
-        <translation type="unfinished">Filigran Resmi</translation>
-    </message>
-    <message>
-        <source>Update</source>
-        <translation type="unfinished">Güncelle</translation>
-    </message>
-    <message>
-        <source>Rotate Watermark</source>
-        <translation type="unfinished">Filigrani Döndür</translation>
-    </message>
-    <message>
-        <source>When enabled, Watermark will be added with a rotation of 45°</source>
-        <translation type="unfinished">Etkinleştirildiğinde, filigran 45 derece açıyla eklenecektir.</translation>
-    </message>
     <message>
         <source>Annotator Settings</source>
         <translation type="unfinished">Yorumcu Ayarları</translation>
@@ -146,6 +164,34 @@ daha düzgün hale getirir.</translation>
         <source>Switch to Select Tool after drawing Item</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number Tool Seed change updates all Number Items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disabling this option causes changes of the number tool
+seed to affect only new items but not existing items.
+Disabling this option allows having duplicate numbers.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Canvas Color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Canvas background color for annotation area.
+Changing color affects only new annotation areas.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Item after drawing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>With this option enabled the item gets selected after
+being created, allowing changing settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -167,32 +213,10 @@ Değişiklik sonrası Ksnip&apos;in yeniden başlatılması gerekir.</translatio
         <source>Application Settings</source>
         <translation type="unfinished">Uygulama Ayarları</translation>
     </message>
-    <message>
-        <source>Use Tray Icon</source>
-        <translation type="unfinished">Pencere Iconu Kullan</translation>
-    </message>
-    <message>
-        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
-Change requires restart.</source>
-        <translation>Etkinleştirildiğinde, işletim sisteminin pencere yöneticisi destekliyorsa görev çubuğuna bir tepsi simgesi ekleyecektir.
-Değişiklik yeniden başlatma gerektirir.</translation>
-    </message>
-    <message>
-        <source>Minimize to Tray</source>
-        <translation type="unfinished">Pencereyi küçült</translation>
-    </message>
-    <message>
-        <source>Close to Tray</source>
-        <translation type="unfinished">Görev çubuğuna küçült</translation>
-    </message>
     <message>
         <source>Automatically copy new captures to clipboard</source>
         <translation type="unfinished">Yeni kayıtları otomatik olarak kopyala</translation>
     </message>
-    <message>
-        <source>Auto Hide Tabs</source>
-        <translation type="unfinished">Pencelereleri otomatik gizle</translation>
-    </message>
     <message>
         <source>Use Tabs</source>
         <translation type="unfinished">Pencereleri kullan</translation>
@@ -205,10 +229,6 @@ Değişiklik yeniden başlatma gerektirir.</translation>
         <source>Run ksnip as single instance</source>
         <translation>Ksnip tek örnek olarak çalışsın</translation>
     </message>
-    <message>
-        <source>Start Minimized to Tray</source>
-        <translation type="unfinished">Küçültülmüş durumda başlat</translation>
-    </message>
     <message>
         <source>Hide Tabbar when only one Tab is used.</source>
         <translation>Yalnızca tek sekme kullanıldığında, sekme çubuğunu gizle.</translation>
@@ -224,13 +244,30 @@ a new start of all instances.</source>
         <source>Remember Main Window position on move and load on startup</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Auto hide Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>On startup hide Toolbar and Annotation Settings.
+Docks visibility can be toggled with the Tab Key.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto resize to content</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically resize Main Window to fit content image.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
-    <message>
-        <source>The Author:</source>
-        <translation type="unfinished">Yazar:</translation>
-    </message>
     <message>
         <source>Contributors:</source>
         <translation type="unfinished">Katkıcılar:</translation>
@@ -264,7 +301,7 @@ a new start of all instances.</source>
         <translation>Snap &amp; Flatpak Desteği</translation>
     </message>
     <message>
-        <source>Feature Implementation</source>
+        <source>The Authors:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -286,60 +323,82 @@ Do you want to save it?</source>
         <source>New</source>
         <translation>Yeni</translation>
     </message>
-    <message>
-        <source>Rectangular Area</source>
-        <translation>Alan Seçimi</translation>
-    </message>
     <message>
         <source>Draw a rectangular area with your mouse</source>
         <translation>Farenizle dikdörtgen bir alan çizin</translation>
     </message>
-    <message>
-        <source>Full Screen (All Monitors)</source>
-        <translation>Tam Ekran (Tüm Ekranlar)</translation>
-    </message>
     <message>
         <source>Capture full screen including all monitors</source>
         <translation>Tüm ekranlar dahil tam ekran görüntü yakalama</translation>
     </message>
-    <message>
-        <source>Current Screen</source>
-        <translation>Geçerli Ekran</translation>
-    </message>
     <message>
         <source>Capture screen where the mouse is located</source>
         <translation>Farenin bulunduğu ekranı yakalayın</translation>
     </message>
-    <message>
-        <source>Active Window</source>
-        <translation>Etkin Pencere</translation>
-    </message>
     <message>
         <source>Capture window that currently has focus</source>
         <translation>Odaklanılan mevcut pencereyi yakala</translation>
     </message>
-    <message>
-        <source>Window Under Cursor</source>
-        <translation>İmleç Altındaki Pencere</translation>
-    </message>
     <message>
         <source>Capture that is currently under the mouse cursor</source>
         <translation>Fare imlecinin altında olanı yakala</translation>
     </message>
-    <message>
-        <source>Last Rectangular Area</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Capture a screenshot of the last selected rectangular area</source>
         <translation type="unfinished">En son seçilen bölgeyi seç</translation>
     </message>
     <message>
-        <source>Screenshot Portal</source>
+        <source>Uses the screenshot Portal for taking screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ContactTab</name>
+    <message>
+        <source>Community</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Uses the screenshot Portal for taking screenshot</source>
+        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>please join our </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> server.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bug Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please use </source>
+        <translation type="unfinished">Hata raporlaması için lütfen </translation>
+    </message>
+    <message>
+        <source> to report bugs.</source>
+        <translation type="unfinished"> sayfasını kullanın.</translation>
+    </message>
+</context>
+<context>
+    <name>CopyAsDataUriOperation</name>
+    <message>
+        <source>Failed to copy to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to copy to clipboard as base64 encoded image.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard as base64 encoded image.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -386,6 +445,44 @@ Do you want to continue?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>EmptyActionSettingTab</name>
+    <message>
+        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>EnumTranslator</name>
+    <message>
+        <source>Rectangular Area</source>
+        <translation type="unfinished">Alan Seçimi</translation>
+    </message>
+    <message>
+        <source>Last Rectangular Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Full Screen (All Monitors)</source>
+        <translation type="unfinished">Tam Ekran (Tüm Ekranlar)</translation>
+    </message>
+    <message>
+        <source>Current Screen</source>
+        <translation type="unfinished">Geçerli Ekran</translation>
+    </message>
+    <message>
+        <source>Active Window</source>
+        <translation type="unfinished">Etkin Pencere</translation>
+    </message>
+    <message>
+        <source>Window Under Cursor</source>
+        <translation type="unfinished">İmleç Altındaki Pencere</translation>
+    </message>
+    <message>
+        <source>Screenshot Portal</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
@@ -475,10 +572,6 @@ Do you want to continue?</source>
         <source>Global HotKeys</source>
         <translation type="unfinished">Evrensel Kısayollar</translation>
     </message>
-    <message>
-        <source>HotKeys are currently supported only for Windows and X11</source>
-        <translation type="unfinished">Kısayollar şimdilik sadece Windows ve X11 de desteklenmektedir</translation>
-    </message>
     <message>
         <source>Capture Last Rect Area</source>
         <translation type="unfinished">Son Seçimi Kaydet</translation>
@@ -491,6 +584,11 @@ Do you want to continue?</source>
         <source>Capture using Portal</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>HotKeys are currently supported only for Windows and X11.
+Disabling this option makes also the action shortcuts ksnip only.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImageGrabberSettings</name>
@@ -504,66 +602,10 @@ screenshots.</source>
         <translation type="unfinished">Ekran görüntüsünde fare imleci
 gözükür.</translation>
     </message>
-    <message>
-        <source>Freeze Image while snipping</source>
-        <translation type="unfinished">Seçim yaparken arka alanı dondur</translation>
-    </message>
-    <message>
-        <source>Show magnifying glass on snipping area</source>
-        <translation type="unfinished">Seçim alanında büyüteç göster</translation>
-    </message>
-    <message>
-        <source>Show a magnifying glass which zooms into
-the background image. This option only works
-with &apos;Freeze Image while snipping&apos; enabled.</source>
-        <translation type="unfinished">Arkaplan görüntüsüne yakınlaştırma yapan bir 
-büyüteç gösterilir. Bu seçenek yalnızca &apos;Seçim 
-yaparken arka alanı dondur&apos; etkinken çalışır.</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area rulers</source>
-        <translation type="unfinished">Seçim Alanı cetvellerini göster</translation>
-    </message>
-    <message>
-        <source>Horizontal and vertical lines going from
-desktop edges to cursor on snipping area.</source>
-        <translation type="unfinished">Seçim yaparken dikey ve yatay cetvellerin
-gösterilmesini sağlar.</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area position and size info</source>
-        <translation type="unfinished">Seçim alanı konumu ve boyut bilgisini göster</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor color</source>
-        <translation type="unfinished">Seçim Alanı imleç rengi</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor thickness</source>
-        <translation type="unfinished">Seçim Alanı imleç kalınlığı</translation>
-    </message>
     <message>
         <source>Image Grabber</source>
         <translation type="unfinished">Görüntü Yakalayıcı</translation>
     </message>
-    <message>
-        <source>When enabled will freeze the background while
-selecting a rectangular region. It also changes
-the behavior of delayed screenshots, with this
-option enabled the delay happens before the
-snipping area is shown and with the option disabled
-the delay happens after the snipping area is shown.
-This feature is always disabled for Wayland and always
-enabled for MacOs.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When left mouse button is not pressed the position
-is shown, when the mouse button is pressed,
-the size of the select area is shown left
-and above from the captured area.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Force Generic Wayland Screenshot</source>
         <translation type="unfinished"></translation>
@@ -592,22 +634,6 @@ Change in this option require a ksnip restart.</source>
         <source>Show Main Window after capturing screenshot</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Show Main Window after capturing a new screenshot
-when the Main Window was hidden or minimized.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Allow resizing rect area selection</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When enabled will, after selecting a rect
-area, allow resizing the selection. When
-done resizing the selection can be confirmed
-by pressing return.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Hide Main Window during screenshot</source>
         <translation type="unfinished"></translation>
@@ -617,11 +643,8 @@ by pressing return.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Sets the color of the snipping area cursor.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sets the thickness of the snipping area cursor.</source>
+        <source>Show Main Window after capturing a new screenshot
+when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -713,10 +736,6 @@ by pressing return.</source>
         <source>Waiting for imgur.com…</source>
         <translation>Imgur.com bekleniyor…</translation>
     </message>
-    <message>
-        <source>Username:</source>
-        <translation type="unfinished">Kullanıcı adı:</translation>
-    </message>
     <message>
         <source>Imgur.com token successfully updated.</source>
         <translation>Imgur.com belirteci başarıyla güncellendi.</translation>
@@ -742,6 +761,21 @@ by pressing return.</source>
 Changing requires restart.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clear Token</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoadImageFromFileOperation</name>
+    <message>
+        <source>Unable to open image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open image from path %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainToolBar</name>
@@ -826,10 +860,6 @@ ve ekran görüntüsünü yakalanır.</translation>
         <source>Scale</source>
         <translation>Ölçekle</translation>
     </message>
-    <message>
-        <source>Scale Screen Capture</source>
-        <translation>Yakalanan Ekran Görüntüsünü Ölçekle</translation>
-    </message>
     <message>
         <source>Quit</source>
         <translation>Kapat</translation>
@@ -890,10 +920,6 @@ ve ekran görüntüsünü yakalanır.</translation>
         <source>Paste Embedded</source>
         <translation type="unfinished">Gömülü Yapıştır</translation>
     </message>
-    <message>
-        <source>Upload capture to external source</source>
-        <translation type="unfinished">Seçimi harici kaynağa yükle</translation>
-    </message>
     <message>
         <source>Pin</source>
         <translation>Sabitle</translation>
@@ -930,6 +956,46 @@ ve ekran görüntüsünü yakalanır.</translation>
         <source>Open Images</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy as data URI</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open &amp;Recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify Canvas</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload triggerCapture to external source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy triggerCapture to system clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate Image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1205,6 +1271,176 @@ When omitted, everything is copied.</source>
         <source>Stickers</source>
         <translation type="unfinished">Etiketler</translation>
     </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Watermark</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaResizerInfoText</name>
+    <message>
+        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys to move the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSelectorInfoText</name>
+    <message>
+        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to resize selection after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Operation will be canceled after 60 sec when no selection made.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSettings</name>
+    <message>
+        <source>Freeze Image while snipping</source>
+        <translation type="unfinished">Seçim yaparken arka alanı dondur</translation>
+    </message>
+    <message>
+        <source>When enabled will freeze the background while
+selecting a rectangular region. It also changes
+the behavior of delayed screenshots, with this
+option enabled the delay happens before the
+snipping area is shown and with the option disabled
+the delay happens after the snipping area is shown.
+This feature is always disabled for Wayland and always
+enabled for MacOs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show magnifying glass on snipping area</source>
+        <translation type="unfinished">Seçim alanında büyüteç göster</translation>
+    </message>
+    <message>
+        <source>Show a magnifying glass which zooms into
+the background image. This option only works
+with &apos;Freeze Image while snipping&apos; enabled.</source>
+        <translation type="unfinished">Arkaplan görüntüsüne yakınlaştırma yapan bir 
+büyüteç gösterilir. Bu seçenek yalnızca &apos;Seçim 
+yaparken arka alanı dondur&apos; etkinken çalışır.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area rulers</source>
+        <translation type="unfinished">Seçim Alanı cetvellerini göster</translation>
+    </message>
+    <message>
+        <source>Horizontal and vertical lines going from
+desktop edges to cursor on snipping area.</source>
+        <translation type="unfinished">Seçim yaparken dikey ve yatay cetvellerin
+gösterilmesini sağlar.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area position and size info</source>
+        <translation type="unfinished">Seçim alanı konumu ve boyut bilgisini göster</translation>
+    </message>
+    <message>
+        <source>When left mouse button is not pressed the position
+is shown, when the mouse button is pressed,
+the size of the select area is shown left
+and above from the captured area.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow resizing rect area selection by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will, after selecting a rect
+area, allow resizing the selection. When
+done resizing the selection can be confirmed
+by pressing return.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Snipping Area info text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor color</source>
+        <translation type="unfinished">Seçim Alanı imleç rengi</translation>
+    </message>
+    <message>
+        <source>Sets the color of the snipping area cursor.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor thickness</source>
+        <translation type="unfinished">Seçim Alanı imleç kalınlığı</translation>
+    </message>
+    <message>
+        <source>Sets the thickness of the snipping area cursor.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area adorner color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sets the color of all adorner elements
+on the snipping area.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area Transparency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Alpha for not selected region on snipping area.
+Smaller number is more transparent.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
@@ -1248,6 +1484,64 @@ When omitted, everything is copied.</source>
         <translation type="unfinished">Düzenleyici Göster</translation>
     </message>
 </context>
+<context>
+    <name>TrayIconSettings</name>
+    <message>
+        <source>Use Tray Icon</source>
+        <translation type="unfinished">Pencere Iconu Kullan</translation>
+    </message>
+    <message>
+        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
+Change requires restart.</source>
+        <translation type="unfinished">Etkinleştirildiğinde, işletim sisteminin pencere yöneticisi destekliyorsa görev çubuğuna bir tepsi simgesi ekleyecektir.
+Değişiklik yeniden başlatma gerektirir.</translation>
+    </message>
+    <message>
+        <source>Minimize to Tray</source>
+        <translation type="unfinished">Pencereyi küçült</translation>
+    </message>
+    <message>
+        <source>Start Minimized to Tray</source>
+        <translation type="unfinished">Küçültülmüş durumda başlat</translation>
+    </message>
+    <message>
+        <source>Close to Tray</source>
+        <translation type="unfinished">Görev çubuğuna küçült</translation>
+    </message>
+    <message>
+        <source>Show Editor</source>
+        <translation type="unfinished">Düzenleyici Göster</translation>
+    </message>
+    <message>
+        <source>Capture</source>
+        <translation type="unfinished">Yakala</translation>
+    </message>
+    <message>
+        <source>Default Tray Icon action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Action that is triggered by left clicking the tray icon.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display Tray icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use platform specific notification service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will use try to use platform specific notification
+service when such exists. Change requires restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>UpdateWatermarkOperation</name>
     <message>
@@ -1320,4 +1614,27 @@ When omitted, everything is copied.</source>
         <translation type="unfinished">Kullanım:</translation>
     </message>
 </context>
+<context>
+    <name>WatermarkSettings</name>
+    <message>
+        <source>Watermark Image</source>
+        <translation type="unfinished">Filigran Resmi</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation type="unfinished">Güncelle</translation>
+    </message>
+    <message>
+        <source>Rotate Watermark</source>
+        <translation type="unfinished">Filigrani Döndür</translation>
+    </message>
+    <message>
+        <source>When enabled, Watermark will be added with a rotation of 45°</source>
+        <translation type="unfinished">Etkinleştirildiğinde, filigran 45 derece açıyla eklenecektir.</translation>
+    </message>
+    <message>
+        <source>Watermark Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
