@@ -29,7 +29,7 @@
     </message>
     <message>
         <source>Contact</source>
-        <translation type="unfinished"></translation>
+        <translation>联系</translation>
     </message>
 </context>
 <context>
@@ -40,81 +40,81 @@
     </message>
     <message>
         <source>Screenshot and Annotation Tool</source>
-        <translation type="unfinished"></translation>
+        <translation>屏幕截图和注释工具</translation>
     </message>
 </context>
 <context>
     <name>ActionSettingTab</name>
     <message>
         <source>Name</source>
-        <translation type="unfinished"></translation>
+        <translation>名称</translation>
     </message>
     <message>
         <source>Shortcut</source>
-        <translation type="unfinished"></translation>
+        <translation>快捷键</translation>
     </message>
     <message>
         <source>Clear</source>
-        <translation type="unfinished">清除</translation>
+        <translation>清除</translation>
     </message>
     <message>
         <source>Take Capture</source>
-        <translation type="unfinished"></translation>
+        <translation>捕获</translation>
     </message>
     <message>
         <source>Include Cursor</source>
-        <translation type="unfinished"></translation>
+        <translation>包含光标</translation>
     </message>
     <message>
         <source>Delay</source>
-        <translation type="unfinished"></translation>
+        <translation>延迟</translation>
     </message>
     <message>
         <source>s</source>
-        <translation type="unfinished">秒</translation>
+        <translation>s</translation>
     </message>
     <message>
         <source>Capture Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>捕获模式</translation>
     </message>
     <message>
         <source>Show image in Pin Window</source>
-        <translation type="unfinished"></translation>
+        <translation>在图钉窗口中显示图像</translation>
     </message>
     <message>
         <source>Copy image to Clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>图像复制到剪贴板</translation>
     </message>
     <message>
         <source>Upload image</source>
-        <translation type="unfinished"></translation>
+        <translation>上传图像</translation>
     </message>
     <message>
         <source>Open image parent directory</source>
-        <translation type="unfinished"></translation>
+        <translation>打开图像父目录</translation>
     </message>
     <message>
         <source>Save image</source>
-        <translation type="unfinished"></translation>
+        <translation>保存图像</translation>
     </message>
     <message>
         <source>Hide Main Window</source>
-        <translation type="unfinished"></translation>
+        <translation>隐藏主窗口</translation>
     </message>
 </context>
 <context>
     <name>ActionsSettings</name>
     <message>
         <source>Add</source>
-        <translation type="unfinished">添加</translation>
+        <translation>添加</translation>
     </message>
     <message>
         <source>Actions Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>操作设置</translation>
     </message>
     <message>
         <source>Action</source>
-        <translation type="unfinished"></translation>
+        <translation>操作</translation>
     </message>
 </context>
 <context>
@@ -137,7 +137,8 @@
     <message>
         <source>When enabled smooths out pen and
 marker paths after finished drawing.</source>
-        <translation>启用时平滑处理笔和标记路径完成后的绘制内容。</translation>
+        <translation>如启用，绘制完成后
+消除笔和标记路径。</translation>
     </message>
     <message>
         <source>Smooth Factor</source>
@@ -165,13 +166,15 @@ make them more smooth.</source>
     </message>
     <message>
         <source>Number Tool Seed change updates all Number Items</source>
-        <translation type="unfinished"></translation>
+        <translation>数字工具种子更改将更新所有数字项目</translation>
     </message>
     <message>
         <source>Disabling this option causes changes of the number tool
 seed to affect only new items but not existing items.
 Disabling this option allows having duplicate numbers.</source>
-        <translation type="unfinished"></translation>
+        <translation>禁用此选项将导致数字工具的更改
+种子仅影响新项目，而不影响现有项目。
+禁用此选项将允许重复的数字。</translation>
     </message>
     <message>
         <source>Canvas Color</source>
@@ -185,12 +188,13 @@ Changing color affects only new annotation areas.</source>
     </message>
     <message>
         <source>Select Item after drawing</source>
-        <translation type="unfinished"></translation>
+        <translation>绘图后选择项目</translation>
     </message>
     <message>
         <source>With this option enabled the item gets selected after
 being created, allowing changing settings.</source>
-        <translation type="unfinished"></translation>
+        <translation>启用此选项后，将在创建项目后对其进行选择，
+从而可以更改设置。</translation>
     </message>
 </context>
 <context>
@@ -245,7 +249,7 @@ a new start of all instances.</source>
     </message>
     <message>
         <source>Remember Main Window position on move and load on startup</source>
-        <translation type="unfinished"></translation>
+        <translation>在移动时记住主窗口的位置并在启动时加载</translation>
     </message>
     <message>
         <source>Auto hide Tabs</source>
@@ -253,20 +257,21 @@ a new start of all instances.</source>
     </message>
     <message>
         <source>Auto hide Docks</source>
-        <translation type="unfinished"></translation>
+        <translation>自动隐藏 Docks</translation>
     </message>
     <message>
         <source>On startup hide Toolbar and Annotation Settings.
 Docks visibility can be toggled with the Tab Key.</source>
-        <translation type="unfinished"></translation>
+        <translation>在启动时隐藏工具栏和注释器，
+可以按下 Tab 键显示 Dock。</translation>
     </message>
     <message>
         <source>Auto resize to content</source>
-        <translation type="unfinished"></translation>
+        <translation>自动调整内容大小</translation>
     </message>
     <message>
         <source>Automatically resize Main Window to fit content image.</source>
-        <translation type="unfinished"></translation>
+        <translation>自动调整主窗口的大小以适合内容图像。</translation>
     </message>
 </context>
 <context>
@@ -353,38 +358,38 @@ Do you want to save it?</source>
     </message>
     <message>
         <source>Uses the screenshot Portal for taking screenshot</source>
-        <translation type="unfinished"></translation>
+        <translation>使用 the screenshot Portal 截图</translation>
     </message>
 </context>
 <context>
     <name>ContactTab</name>
     <message>
         <source>Community</source>
-        <translation type="unfinished"></translation>
+        <translation>社区</translation>
     </message>
     <message>
         <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation type="unfinished"></translation>
+        <translation>如果您有一般性问题，想法或只想谈谈 ksnip，</translation>
     </message>
     <message>
         <source>please join our </source>
-        <translation type="unfinished"></translation>
+        <translation>请加入我们 </translation>
     </message>
     <message>
         <source> server.</source>
-        <translation type="unfinished"></translation>
+        <translation> 服务。</translation>
     </message>
     <message>
         <source>Bug Reports</source>
-        <translation type="unfinished"></translation>
+        <translation>错误报告</translation>
     </message>
     <message>
         <source>Please use </source>
-        <translation type="unfinished">请使用 </translation>
+        <translation>请使用 </translation>
     </message>
     <message>
         <source> to report bugs.</source>
-        <translation type="unfinished"> 报告错误。</translation>
+        <translation> 报告错误。</translation>
     </message>
 </context>
 <context>
@@ -399,11 +404,11 @@ Do you want to save it?</source>
     </message>
     <message>
         <source>Copied to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>已复制到剪切板</translation>
     </message>
     <message>
         <source>Copied to clipboard as base64 encoded image.</source>
-        <translation type="unfinished"></translation>
+        <translation>已将图像的 base64 编码复制到剪切板。</translation>
     </message>
 </context>
 <context>
@@ -443,18 +448,18 @@ Do you want to continue?</source>
     </message>
     <message>
         <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation type="unfinished"></translation>
+        <translation>ksnip 是一个非盈利的公共版权自由软件项目，&lt;br/&gt; 仍有一些成本需要支付，&lt;br/&gt; 比如域名成本和跨平台支持所需的硬件成本。</translation>
     </message>
     <message>
         <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation type="unfinished"></translation>
+        <translation>如果您想请开发人员喝杯啤酒或咖啡或只是想&lt;br/&gt;欣赏正在完成的工作&lt;br/&gt;，则可以这样做</translation>
     </message>
 </context>
 <context>
     <name>EmptyActionSettingTab</name>
     <message>
         <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
-        <translation type="unfinished"></translation>
+        <translation>通过点击“添加”标签按钮来添加新的操作。</translation>
     </message>
 </context>
 <context>
@@ -485,7 +490,7 @@ Do you want to continue?</source>
     </message>
     <message>
         <source>Screenshot Portal</source>
-        <translation type="unfinished"></translation>
+        <translation>截图门户</translation>
     </message>
 </context>
 <context>
@@ -587,12 +592,13 @@ Do you want to continue?</source>
     </message>
     <message>
         <source>Capture using Portal</source>
-        <translation type="unfinished"></translation>
+        <translation>使用 Portal 捕获</translation>
     </message>
     <message>
         <source>HotKeys are currently supported only for Windows and X11.
 Disabling this option makes also the action shortcuts ksnip only.</source>
-        <translation type="unfinished"></translation>
+        <translation>当前仅 Windows 和 X11 支持热键。
+禁用此选项也会使仅 ksnip 操作快捷方式。</translation>
     </message>
 </context>
 <context>
@@ -613,11 +619,11 @@ screenshots.</source>
     </message>
     <message>
         <source>Force Generic Wayland Screenshot</source>
-        <translation type="unfinished"></translation>
+        <translation>强制通用 Wayland 截图</translation>
     </message>
     <message>
         <source>Scale Generic Wayland Screenshots</source>
-        <translation type="unfinished"></translation>
+        <translation>缩放通用 Wayland 截图</translation>
     </message>
     <message>
         <source>Generic Wayland implementations that use
@@ -625,7 +631,11 @@ XDG-DESKTOP-PORTAL handle screen scaling
 differently. Enabling this option will
 determine the current screen scaling and
 apply that to the screenshot in ksnip.</source>
-        <translation type="unfinished"></translation>
+        <translation>使用 XDG-DESKTOP-PORTAL 的通用 Wayland 实现
+以不同的方式处理屏幕缩放。
+启用此选项将确定当前屏幕缩放
+并将其
+应用于 ksnip 中的屏幕截图 。</translation>
     </message>
     <message>
         <source>GNOME and KDE Plasma support their own Wayland
@@ -633,7 +643,11 @@ and the Generic XDG-DESKTOP-PORTAL screenshots.
 Enabling this option will force KDE Plasma and
 GNOME to use the XDG-DESKTOP-PORTAL screenshots.
 Change in this option require a ksnip restart.</source>
-        <translation type="unfinished"></translation>
+        <translation>GNOME 和 KDE Plasma 支持各自的Wayland，
+也有通用的 XDG-DESKTOP-PORTAL 屏幕截图。
+启用该选项将强制 KDE Plasma 和 GNOME
+使用 XDG-DESKTOP-PORTAL 截图方式。
+改变这个选项需要重新启动 ksnip。</translation>
     </message>
     <message>
         <source>Show Main Window after capturing screenshot</source>
@@ -650,14 +664,15 @@ Change in this option require a ksnip restart.</source>
     <message>
         <source>Show Main Window after capturing a new screenshot
 when the Main Window was hidden or minimize.</source>
-        <translation type="unfinished"></translation>
+        <translation>隐藏或最小化主窗口时在捕获新的
+屏幕快照后显示主窗口。</translation>
     </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
     <message>
         <source>Imgur History</source>
-        <translation>上传到Imgur的历史信息</translation>
+        <translation>Imgur 历史记录</translation>
     </message>
     <message>
         <source>Close</source>
@@ -688,7 +703,7 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Imgur token has expired, requesting new token…</source>
-        <translation>Imgur令牌已过期，正在请求新令牌…</translation>
+        <translation>Imgur 令牌已过期，正在请求新令牌…</translation>
     </message>
 </context>
 <context>
@@ -699,7 +714,7 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Always copy Imgur link to clipboard</source>
-        <translation>总是将Imgur链接复制到剪贴板</translation>
+        <translation>总是将 Imgur 链接复制到剪贴板</translation>
     </message>
     <message>
         <source>Client ID</source>
@@ -719,7 +734,7 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Get PIN</source>
-        <translation>获得PIN</translation>
+        <translation>获得 PIN</translation>
     </message>
     <message>
         <source>Get Token</source>
@@ -727,7 +742,7 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Imgur History</source>
-        <translation>上传到Imgur的历史信息</translation>
+        <translation>Imgur 历史记录</translation>
     </message>
     <message>
         <source>Imgur Uploader</source>
@@ -739,15 +754,15 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Waiting for imgur.com…</source>
-        <translation>等待imgur.com的回应…</translation>
+        <translation>等待 imgur.com 的回应…</translation>
     </message>
     <message>
         <source>Imgur.com token successfully updated.</source>
-        <translation>Imgur.com令牌已成功更新。</translation>
+        <translation>Imgur.com 令牌已成功更新。</translation>
     </message>
     <message>
         <source>Imgur.com token update error.</source>
-        <translation>Imgur.com令牌更新错误。</translation>
+        <translation>Imgur.com 令牌更新错误。</translation>
     </message>
     <message>
         <source>After uploading open Imgur link in default browser</source>
@@ -759,12 +774,12 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Base Url:</source>
-        <translation type="unfinished"></translation>
+        <translation>基址 URL：</translation>
     </message>
     <message>
         <source>Base url that will be used for communication with Imgur.
 Changing requires restart.</source>
-        <translation>Base url 用来与 Imgur 通信。
+        <translation>基地 URL 用来与 Imgur 通信。
 更改需要重启应用。</translation>
     </message>
     <message>
@@ -813,7 +828,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Copy Screen Capture to clipboard</source>
-        <translation>将屏幕截图复制到剪贴板</translation>
+        <translation>复制屏幕截图到剪贴板</translation>
     </message>
     <message>
         <source>Tools</source>
@@ -928,7 +943,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Pin</source>
-        <translation type="unfinished"></translation>
+        <translation>图钉</translation>
     </message>
     <message>
         <source>Pin screenshot to foreground in frameless window</source>
@@ -964,15 +979,15 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Show Docks</source>
-        <translation type="unfinished"></translation>
+        <translation>显示 Docks</translation>
     </message>
     <message>
         <source>Hide Docks</source>
-        <translation type="unfinished"></translation>
+        <translation>隐藏 Docks</translation>
     </message>
     <message>
         <source>Copy as data URI</source>
-        <translation type="unfinished">复制为数据 URI</translation>
+        <translation>复制为数据 URI</translation>
     </message>
     <message>
         <source>Open &amp;Recent</source>
@@ -980,27 +995,27 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Modify Canvas</source>
-        <translation type="unfinished">修改画布</translation>
+        <translation>修改画布</translation>
     </message>
     <message>
         <source>Upload triggerCapture to external source</source>
-        <translation type="unfinished"></translation>
+        <translation>上传 triggerCapture 到外部源</translation>
     </message>
     <message>
         <source>Copy triggerCapture to system clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>复制 triggerCapture 到系统剪贴板</translation>
     </message>
     <message>
         <source>Scale Image</source>
-        <translation type="unfinished"></translation>
+        <translation>缩放图像</translation>
     </message>
     <message>
         <source>Rotate</source>
-        <translation type="unfinished"></translation>
+        <translation>旋转</translation>
     </message>
     <message>
         <source>Rotate Image</source>
-        <translation type="unfinished"></translation>
+        <translation>旋转图像</translation>
     </message>
 </context>
 <context>
@@ -1143,7 +1158,7 @@ with the latest save directory, for every save.</source>
     </message>
     <message>
         <source>Capture save location and filename</source>
-        <translation type="unfinished">捕获保存位置和文件名</translation>
+        <translation>捕获保存位置和文件名</translation>
     </message>
     <message>
         <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
@@ -1173,7 +1188,7 @@ Filename can contain following wildcards:
     </message>
     <message>
         <source>Factor</source>
-        <translation type="unfinished"></translation>
+        <translation>因子</translation>
     </message>
     <message>
         <source>Save Quality</source>
@@ -1204,7 +1219,7 @@ with the path to a temporary png file as a single argument.</source>
     </message>
     <message>
         <source>Browse</source>
-        <translation type="unfinished">浏览</translation>
+        <translation>浏览</translation>
     </message>
     <message>
         <source>Script Uploader</source>
@@ -1255,7 +1270,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>Imgur Uploader</source>
-        <translation>Imgur上传程序</translation>
+        <translation>Imgur 上传程序</translation>
     </message>
     <message>
         <source>Application</source>
@@ -1271,7 +1286,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>Uploader</source>
-        <translation type="unfinished">上传</translation>
+        <translation>上传程序</translation>
     </message>
     <message>
         <source>Script Uploader</source>
@@ -1287,7 +1302,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>Snipping Area</source>
-        <translation type="unfinished">剪切区域</translation>
+        <translation>截图区域</translation>
     </message>
     <message>
         <source>Tray Icon</source>
@@ -1299,7 +1314,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>Actions</source>
-        <translation type="unfinished"></translation>
+        <translation>操作</translation>
     </message>
 </context>
 <context>
@@ -1341,7 +1356,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>Hold CTRL pressed to prevent resizing after selecting.</source>
-        <translation>选择后，按住CTRL键防止调整大小。</translation>
+        <translation>选择后，按住 CTRL 键防止调整大小。</translation>
     </message>
     <message>
         <source>Operation will be canceled after 60 sec when no selection made.</source>
@@ -1349,14 +1364,14 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>This message can be disabled via settings.</source>
-        <translation type="unfinished">可以通过设置禁用此消息。</translation>
+        <translation>可以通过设置禁用此消息。</translation>
     </message>
 </context>
 <context>
     <name>SnippingAreaSettings</name>
     <message>
         <source>Freeze Image while snipping</source>
-        <translation type="unfinished">截图时冻结图像</translation>
+        <translation>截图时冻结图像</translation>
     </message>
     <message>
         <source>When enabled will freeze the background while
@@ -1367,112 +1382,127 @@ snipping area is shown and with the option disabled
 the delay happens after the snipping area is shown.
 This feature is always disabled for Wayland and always
 enabled for MacOs.</source>
-        <translation type="unfinished"></translation>
+        <translation>启用后将在选择矩形区域时冻结背景。
+它还会更改延迟屏幕截图的行为，
+从而更改了延迟屏幕截图的行为，
+启用此选项将延迟发生在显示剪裁区域之前，
+而禁用此选项
+将延迟发生在显示剪裁区域之后。
+Wayland 始终禁用此功能，
+MacOs 始终启用此功能。</translation>
     </message>
     <message>
         <source>Show magnifying glass on snipping area</source>
-        <translation type="unfinished">在截屏区域显示放大镜</translation>
+        <translation>在截屏区域显示放大镜</translation>
     </message>
     <message>
         <source>Show a magnifying glass which zooms into
 the background image. This option only works
 with &apos;Freeze Image while snipping&apos; enabled.</source>
-        <translation type="unfinished">在背景图片上显示放大镜。
-此选项仅适用启用了“在
-截屏时冻结图像”。</translation>
+        <translation>显示放大背景图的
+放大镜。此设置仅在
+启用了&apos;在截图时冻结图像&apos;时生效。</translation>
     </message>
     <message>
         <source>Show Snipping Area rulers</source>
-        <translation type="unfinished">在截图区域显示标尺</translation>
+        <translation>在截图区域显示标尺</translation>
     </message>
     <message>
         <source>Horizontal and vertical lines going from
 desktop edges to cursor on snipping area.</source>
-        <translation type="unfinished">在截屏时，显示从屏幕边缘跟踪到鼠标
+        <translation>在截屏区域，显示从屏幕边缘到鼠标
 的水平线和垂直线。</translation>
     </message>
     <message>
         <source>Show Snipping Area position and size info</source>
-        <translation type="unfinished">显示截图区域的位置和大小信息</translation>
+        <translation>显示截图区域的位置和尺寸信息</translation>
     </message>
     <message>
         <source>When left mouse button is not pressed the position
 is shown, when the mouse button is pressed,
 the size of the select area is shown left
 and above from the captured area.</source>
-        <translation type="unfinished"></translation>
+        <translation>当未按下鼠标左键时，
+显示位置，
+当按下鼠标按钮时，
+所选区域的大小显示在捕获区域的左上方。</translation>
     </message>
     <message>
         <source>Allow resizing rect area selection by default</source>
-        <translation type="unfinished"></translation>
+        <translation>默认情况下允许调整矩形区域的大小</translation>
     </message>
     <message>
         <source>When enabled will, after selecting a rect
 area, allow resizing the selection. When
 done resizing the selection can be confirmed
 by pressing return.</source>
-        <translation type="unfinished"></translation>
+        <translation>启用后，
+将在选择矩形区域后允许调整选择的大小。
+完成调整大小后，
+可以按回车键确认选择。</translation>
     </message>
     <message>
         <source>Show Snipping Area info text</source>
-        <translation type="unfinished"></translation>
+        <translation>显示截图区域信息文本</translation>
     </message>
     <message>
         <source>Snipping Area cursor color</source>
-        <translation type="unfinished">截图区域的光标颜色</translation>
+        <translation>截图区域的光标颜色</translation>
     </message>
     <message>
         <source>Sets the color of the snipping area cursor.</source>
-        <translation type="unfinished"></translation>
+        <translation>设置剪切区域光标的颜色。</translation>
     </message>
     <message>
         <source>Snipping Area cursor thickness</source>
-        <translation type="unfinished">截图区域的光标粗度</translation>
+        <translation>截图区域的光标粗细</translation>
     </message>
     <message>
         <source>Sets the thickness of the snipping area cursor.</source>
-        <translation type="unfinished"></translation>
+        <translation>设置剪切区域光标的粗细。</translation>
     </message>
     <message>
         <source>Snipping Area</source>
-        <translation type="unfinished">剪切区域</translation>
+        <translation>截屏区域</translation>
     </message>
     <message>
         <source>Snipping Area adorner color</source>
-        <translation type="unfinished"></translation>
+        <translation>截图区域装饰色</translation>
     </message>
     <message>
         <source>Sets the color of all adorner elements
 on the snipping area.</source>
-        <translation type="unfinished"></translation>
+        <translation>设置剪切区域上
+所有装饰元素的颜色。</translation>
     </message>
     <message>
         <source>Snipping Area Transparency</source>
-        <translation type="unfinished"></translation>
+        <translation>截图区域透明度</translation>
     </message>
     <message>
         <source>Alpha for not selected region on snipping area.
 Smaller number is more transparent.</source>
-        <translation type="unfinished"></translation>
+        <translation>剪裁区域中未选择区域的 Alpha。
+数字越小越透明。</translation>
     </message>
 </context>
 <context>
     <name>StickerSettings</name>
     <message>
         <source>Up</source>
-        <translation type="unfinished"></translation>
+        <translation>向上</translation>
     </message>
     <message>
         <source>Down</source>
-        <translation type="unfinished"></translation>
+        <translation>向下</translation>
     </message>
     <message>
         <source>Use Default Stickers</source>
-        <translation type="unfinished"></translation>
+        <translation>使用默认贴纸</translation>
     </message>
     <message>
         <source>Sticker Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>贴纸设置</translation>
     </message>
     <message>
         <source>Vector Image Files (*.svg)</source>
@@ -1488,7 +1518,7 @@ Smaller number is more transparent.</source>
     </message>
     <message>
         <source>Add Stickers</source>
-        <translation type="unfinished"></translation>
+        <translation>添加贴纸</translation>
     </message>
 </context>
 <context>
@@ -1507,8 +1537,8 @@ Smaller number is more transparent.</source>
     <message>
         <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
 Change requires restart.</source>
-        <translation type="unfinished">如果启用，则会在操作系统窗口的任务栏上添加图标（如果支持）。
-更改需要重新启动。</translation>
+        <translation>启用后，如系统窗口管理器支持，会向任务栏添加托盘图标。
+更改需要重新启动才能生效。</translation>
     </message>
     <message>
         <source>Minimize to Tray</source>
@@ -1544,16 +1574,17 @@ Change requires restart.</source>
     </message>
     <message>
         <source>Display Tray icon notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>显示任务栏图标通知</translation>
     </message>
     <message>
         <source>Use platform specific notification service</source>
-        <translation type="unfinished"></translation>
+        <translation>使用平台特定的通知服务</translation>
     </message>
     <message>
         <source>When enabled will use try to use platform specific notification
 service when such exists. Change requires restart to take effect.</source>
-        <translation type="unfinished"></translation>
+        <translation>启用后将使用尝试使用特定于平台的通知存在时提供服务。
+ 更改需要重新启动才能生效。</translation>
     </message>
 </context>
 <context>
@@ -1579,11 +1610,11 @@ service when such exists. Change requires restart to take effect.</source>
     </message>
     <message>
         <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
-        <translation type="unfinished"></translation>
+        <translation>请通过选项&gt;设置&gt;上传脚本添加一个上传脚本</translation>
     </message>
     <message>
         <source>Capture Upload</source>
-        <translation type="unfinished"></translation>
+        <translation>捕获上传</translation>
     </message>
     <message>
         <source>You are about to upload the image to an external destination, do you want to proceed?</source>
@@ -1594,7 +1625,7 @@ service when such exists. Change requires restart to take effect.</source>
     <name>UploaderSettings</name>
     <message>
         <source>Ask for confirmation before uploading</source>
-        <translation type="unfinished">上传前要求确认</translation>
+        <translation>上传前请求确认</translation>
     </message>
     <message>
         <source>Uploader Type:</source>
@@ -1610,7 +1641,7 @@ service when such exists. Change requires restart to take effect.</source>
     </message>
     <message>
         <source>Uploader</source>
-        <translation type="unfinished">上传</translation>
+        <translation>上传程序</translation>
     </message>
 </context>
 <context>
@@ -1632,19 +1663,19 @@ service when such exists. Change requires restart to take effect.</source>
     <name>WatermarkSettings</name>
     <message>
         <source>Watermark Image</source>
-        <translation type="unfinished">水印图像</translation>
+        <translation>水印图像</translation>
     </message>
     <message>
         <source>Update</source>
-        <translation type="unfinished">更新</translation>
+        <translation>更新</translation>
     </message>
     <message>
         <source>Rotate Watermark</source>
-        <translation type="unfinished">旋转水印</translation>
+        <translation>旋转水印</translation>
     </message>
     <message>
         <source>When enabled, Watermark will be added with a rotation of 45°</source>
-        <translation type="unfinished">启用后，水印将旋转45度</translation>
+        <translation>启用后，将添加旋转 45° 的水印</translation>
     </message>
     <message>
         <source>Watermark Settings</source>
